# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tx_datashard.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from ydb.core.protos import type_info_pb2 as ydb_dot_core_dot_protos_dot_type__info__pb2
from ydb.core.protos import kqp_pb2 as ydb_dot_core_dot_protos_dot_kqp__pb2
from ydb.core.protos import ssa_pb2 as ydb_dot_core_dot_protos_dot_ssa__pb2
from ydb.core.protos import tablet_pb2 as ydb_dot_core_dot_protos_dot_tablet__pb2
from ydb.core.protos import tx_pb2 as ydb_dot_core_dot_protos_dot_tx__pb2
from ydb.core.protos import flat_scheme_op_pb2 as ydb_dot_core_dot_protos_dot_flat__scheme__op__pb2
from ydb.core.protos import table_stats_pb2 as ydb_dot_core_dot_protos_dot_table__stats__pb2
from ydb.core.protos import subdomains_pb2 as ydb_dot_core_dot_protos_dot_subdomains__pb2
from ydb.core.protos import query_stats_pb2 as ydb_dot_core_dot_protos_dot_query__stats__pb2
from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2
from ydb.public.api.protos import ydb_status_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__status__codes__pb2
from ydb.library.yql.dq.actors.protos import dq_events_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_actors_dot_protos_dot_dq__events__pb2
from ydb.library.yql.dq.actors.protos import dq_stats_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_actors_dot_protos_dot_dq__stats__pb2
from ydb.library.yql.dq.proto import dq_tasks_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_proto_dot_dq__tasks__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"ydb/core/protos/tx_datashard.proto\x12\x12NKikimrTxDataShard\x1a&library/cpp/actors/protos/actors.proto\x1a\x1aydb/core/protos/base.proto\x1a\x1fydb/core/protos/type_info.proto\x1a\x19ydb/core/protos/kqp.proto\x1a\x19ydb/core/protos/ssa.proto\x1a\x1cydb/core/protos/tablet.proto\x1a\x18ydb/core/protos/tx.proto\x1a$ydb/core/protos/flat_scheme_op.proto\x1a!ydb/core/protos/table_stats.proto\x1a ydb/core/protos/subdomains.proto\x1a!ydb/core/protos/query_stats.proto\x1a-ydb/public/api/protos/ydb_issue_message.proto\x1a,ydb/public/api/protos/ydb_status_codes.proto\x1a\x30ydb/library/yql/dq/actors/protos/dq_events.proto\x1a/ydb/library/yql/dq/actors/protos/dq_stats.proto\x1a\'ydb/library/yql/dq/proto/dq_tasks.proto\x1a\x1bgoogle/protobuf/empty.proto\":\n\x10TEvGetShardState\x12&\n\x06Source\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\"I\n\x16TEvGetShardStateResult\x12\x0e\n\x06Origin\x18\x01 \x01(\x04\x12\r\n\x05State\x18\x02 \x01(\r\x12\x10\n\x08\x44ropTxId\x18\x03 \x01(\x04\"a\n\x0eTShardOpResult\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x0f\n\x07\x45xplain\x18\x02 \x01(\t\x12\x16\n\x0e\x42ytesProcessed\x18\x03 \x01(\x04\x12\x15\n\rRowsProcessed\x18\x04 \x01(\x04\"\xbf\x01\n\x10TEvSchemaChanged\x12&\n\x06Source\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\r\n\x05State\x18\x03 \x01(\r\x12\x0c\n\x04TxId\x18\x04 \x01(\x04\x12\x0c\n\x04Step\x18\x05 \x01(\x04\x12\x12\n\nGeneration\x18\x06 \x01(\r\x12\x34\n\x08OpResult\x18\x07 \x01(\x0b\x32\".NKikimrTxDataShard.TShardOpResult\"&\n\x16TEvSchemaChangedResult\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\"Z\n\x0fTEvStateChanged\x12&\n\x06Source\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\x12\r\n\x05State\x18\x03 \x01(\r\"8\n\x15TEvStateChangedResult\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\r\n\x05State\x18\x02 \x01(\r\"\x10\n\x0eTRWTransaction\"\x10\n\x0eTROTransaction\"C\n\x08TTableId\x12\x0f\n\x07OwnerId\x18\x01 \x01(\x04\x12\x0f\n\x07TableId\x18\x02 \x01(\x04\x12\x15\n\rSchemaVersion\x18\x03 \x01(\x04\"\xcf\x02\n\x15TReadTableTransaction\x12-\n\x07TableId\x18\x01 \x01(\x0b\x32\x1c.NKikimrTxDataShard.TTableId\x12\x42\n\x07\x43olumns\x18\x02 \x03(\x0b\x32\x31.NKikimrTxDataShard.TReadTableTransaction.TColumn\x12#\n\x05Range\x18\x03 \x01(\x0b\x32\x14.NKikimrTx.TKeyRange\x12\x12\n\nApiVersion\x18\x04 \x01(\r\x12\x14\n\x0cSnapshotStep\x18\x05 \x01(\x04\x12\x14\n\x0cSnapshotTxId\x18\x06 \x01(\x04\x1a^\n\x07TColumn\x12\n\n\x02Id\x18\x01 \x01(\r\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x0e\n\x06TypeId\x18\x03 \x01(\r\x12)\n\x08TypeInfo\x18\x04 \x01(\x0b\x32\x17.NKikimrProto.TTypeInfo\"\xde\x01\n\tTKqpLocks\x12(\n\x05Locks\x18\x01 \x03(\x0b\x32\x19.NKikimrTxDataShard.TLock\x12\x15\n\rSendingShards\x18\x02 \x03(\x04\x12\x17\n\x0fReceivingShards\x18\x03 \x03(\x04\x12\x32\n\x02Op\x18\x04 \x01(\x0e\x32&.NKikimrTxDataShard.TKqpLocks.ELocksOp\"C\n\x08\x45LocksOp\x12\x0f\n\x0bUnspecified\x10\x00\x12\x0c\n\x08Validate\x10\x01\x12\n\n\x06\x43ommit\x10\x02\x12\x0c\n\x08Rollback\x10\x03\"Z\n\x17TKqpValidateLocksResult\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12.\n\x0b\x42rokenLocks\x18\x02 \x03(\x0b\x32\x19.NKikimrTxDataShard.TLock\"\xcf\x10\n\x0fTKqpTransaction\x12\x35\n\x04Type\x18\x01 \x01(\x0e\x32\'.NKikimrTxDataShard.EKqpTransactionType\x12%\n\x05Tasks\x18\x02 \x03(\x0b\x32\x16.NYql.NDqProto.TDqTask\x12,\n\x05Locks\x18\x03 \x01(\x0b\x32\x1d.NKikimrTxDataShard.TKqpLocks\x12?\n\x0fRuntimeSettings\x18\x04 \x01(\x0b\x32&.NYql.NDqProto.TComputeRuntimeSettings\x12*\n\x08Snapshot\x18\x06 \x01(\x0b\x32\x18.NKikimrKqp.TKqpSnapshot\x12!\n\x12UseGenericReadSets\x18\x07 \x01(\x08:\x05\x66\x61lse\x1a`\n\x0bTColumnMeta\x12\n\n\x02Id\x18\x01 \x01(\r\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x0c\n\x04Type\x18\x03 \x01(\r\x12)\n\x08TypeInfo\x18\x04 \x01(\x0b\x32\x17.NKikimrProto.TTypeInfo\x1an\n\x10TColumnWriteMeta\x12?\n\x06\x43olumn\x18\x01 \x01(\x0b\x32/.NKikimrTxDataShard.TKqpTransaction.TColumnMeta\x12\x19\n\x11MaxValueSizeBytes\x18\x02 \x01(\r\x1aL\n\x0eTTableKeyRange\x12\'\n\tKeyRanges\x18\x01 \x03(\x0b\x32\x14.NKikimrTx.TKeyRange\x12\x11\n\tKeyPoints\x18\x02 \x03(\x0c\x1a\x8d\x01\n\nTTableMeta\x12-\n\x07TableId\x18\x01 \x01(\x0b\x32\x1c.NKikimrTxDataShard.TTableId\x12\x11\n\tTablePath\x18\x02 \x01(\t\x12\x15\n\rSchemaVersion\x18\x03 \x01(\x04\x12\x13\n\x0bSysViewInfo\x18\x05 \x01(\t\x12\x11\n\tTableKind\x18\x06 \x01(\r\x1a\xf1\x05\n\rTDataTaskMeta\x12=\n\x05Table\x18\x01 \x01(\x0b\x32..NKikimrTxDataShard.TKqpTransaction.TTableMeta\x12L\n\x05Reads\x18\x02 \x03(\x0b\x32=.NKikimrTxDataShard.TKqpTransaction.TDataTaskMeta.TReadOpMeta\x12N\n\x06Writes\x18\x03 \x01(\x0b\x32>.NKikimrTxDataShard.TKqpTransaction.TDataTaskMeta.TWriteOpMeta\x1a\x84\x01\n\tTKeyRange\x12)\n\tFullRange\x18\x01 \x01(\x0b\x32\x14.NKikimrTx.TKeyRangeH\x00\x12\x44\n\x06Ranges\x18\x02 \x01(\x0b\x32\x32.NKikimrTxDataShard.TKqpTransaction.TTableKeyRangeH\x00\x42\x06\n\x04Kind\x1a\xc0\x01\n\x0bTReadOpMeta\x12@\n\x07\x43olumns\x18\x01 \x03(\x0b\x32/.NKikimrTxDataShard.TKqpTransaction.TColumnMeta\x12J\n\x05Range\x18\x02 \x01(\x0b\x32;.NKikimrTxDataShard.TKqpTransaction.TDataTaskMeta.TKeyRange\x12\x12\n\nItemsLimit\x18\x03 \x01(\x04\x12\x0f\n\x07Reverse\x18\x04 \x01(\x08\x1a\xb8\x01\n\x0cTWriteOpMeta\x12J\n\x05Range\x18\x01 \x01(\x0b\x32;.NKikimrTxDataShard.TKqpTransaction.TDataTaskMeta.TKeyRange\x12\x45\n\x07\x43olumns\x18\x03 \x03(\x0b\x32\x34.NKikimrTxDataShard.TKqpTransaction.TColumnWriteMeta\x12\x15\n\rIsPureEraseOp\x18\x04 \x01(\x08\x1a\xf5\x04\n\rTScanTaskMeta\x12=\n\x05Table\x18\x01 \x01(\x0b\x32..NKikimrTxDataShard.TKqpTransaction.TTableMeta\x12@\n\x07\x43olumns\x18\x02 \x03(\x0b\x32/.NKikimrTxDataShard.TKqpTransaction.TColumnMeta\x12\x16\n\x0eKeyColumnTypes\x18\x03 \x03(\r\x12\x33\n\x12KeyColumnTypeInfos\x18\r \x03(\x0b\x32\x17.NKikimrProto.TTypeInfo\x12\x14\n\x0cSkipNullKeys\x18\x04 \x03(\x08\x12L\n\x05Reads\x18\x05 \x03(\x0b\x32=.NKikimrTxDataShard.TKqpTransaction.TScanTaskMeta.TReadOpMeta\x12\x12\n\nItemsLimit\x18\x06 \x01(\x04\x12\x0f\n\x07Reverse\x18\x07 \x01(\x08\x12\x37\n\nDataFormat\x18\t \x01(\x0e\x32#.NKikimrTxDataShard.EScanDataFormat\x12-\n\x0bOlapProgram\x18\n \x01(\x0b\x32\x18.NKikimrSSA.TOlapProgram\x12\x0e\n\x06Sorted\x18\x0b \x01(\x08\x12\x46\n\rResultColumns\x18\x0c \x03(\x0b\x32/.NKikimrTxDataShard.TKqpTransaction.TColumnMeta\x1aG\n\x0bTReadOpMeta\x12\x0f\n\x07ShardId\x18\x01 \x01(\x04\x12\'\n\tKeyRanges\x18\x02 \x03(\x0b\x32\x14.NKikimrTx.TKeyRangeJ\x04\x08\x08\x10\tJ\x04\x08\x05\x10\x06\"\xfb\x03\n\x1cTKqpReadRangesSourceSettings\x12=\n\x05Table\x18\x01 \x01(\x0b\x32..NKikimrTxDataShard.TKqpTransaction.TTableMeta\x12)\n\tFullRange\x18\x02 \x01(\x0b\x32\x14.NKikimrTx.TKeyRangeH\x00\x12\x44\n\x06Ranges\x18\x03 \x01(\x0b\x32\x32.NKikimrTxDataShard.TKqpTransaction.TTableKeyRangeH\x00\x12@\n\x07\x43olumns\x18\x04 \x03(\x0b\x32/.NKikimrTxDataShard.TKqpTransaction.TColumnMeta\x12\x12\n\nItemsLimit\x18\x05 \x01(\x04\x12\x0f\n\x07Reverse\x18\x06 \x01(\x08\x12\x14\n\x0cSkipNullKeys\x18\x07 \x03(\t\x12\x16\n\x0eKeyColumnTypes\x18\x08 \x03(\r\x12\x37\n\nDataFormat\x18\t \x01(\x0e\x32#.NKikimrTxDataShard.EScanDataFormat\x12+\n\x08Snapshot\x18\n \x01(\x0b\x32\x19.NKikimrProto.TRowVersion\x12\x13\n\x0bShardIdHint\x18\x0b \x01(\x04\x12\x0e\n\x06Sorted\x18\x0c \x01(\x08\x42\x0b\n\tRangeType\"L\n\x0cTKqpTaskInfo\x12\x0e\n\x06TaskId\x18\x01 \x01(\x04\x12,\n\x0c\x43omputeActor\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\"j\n\tTKqpReply\x12,\n\x07Outputs\x18\x01 \x03(\x0b\x32\x1b.NYql.NDqProto.TChannelData\x12/\n\x05Tasks\x18\x02 \x03(\x0b\x32 .NKikimrTxDataShard.TKqpTaskInfo\"\x85\x01\n\x0bTKqpReadset\x12,\n\x07Outputs\x18\x01 \x03(\x0b\x32\x1b.NYql.NDqProto.TChannelData\x12H\n\x13ValidateLocksResult\x18\x02 \x01(\x0b\x32+.NKikimrTxDataShard.TKqpValidateLocksResult\"\xc1\x04\n\x10TDataTransaction\x12\x39\n\rRWTransaction\x18\x01 \x01(\x0b\x32\".NKikimrTxDataShard.TRWTransaction\x12\x39\n\rROTransaction\x18\x02 \x01(\x0b\x32\".NKikimrTxDataShard.TROTransaction\x12\x0f\n\x07MiniKQL\x18\x03 \x01(\x0c\x12\x11\n\tImmediate\x18\x04 \x01(\x08\x12\x10\n\x08LockTxId\x18\x05 \x01(\x06\x12\x17\n\x0fNeedDiagnostics\x18\x06 \x01(\x08\x12\x10\n\x08ReadOnly\x18\x07 \x01(\x08\x12G\n\x14ReadTableTransaction\x18\x08 \x01(\x0b\x32).NKikimrTxDataShard.TReadTableTransaction\x12\x16\n\x0eStreamResponse\x18\t \x01(\x08\x12$\n\x04Sink\x18\n \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x13\n\x0bLlvmRuntime\x18\x0b \x01(\x08\x12\"\n\x1aPerShardKeysSizeLimitBytes\x18\x0c \x01(\x04\x12;\n\x0eKqpTransaction\x18\r \x01(\x0b\x32#.NKikimrTxDataShard.TKqpTransaction\x12\x18\n\x10\x43\x61ncelDeadlineMs\x18\x0e \x01(\x04\x12\x15\n\rCancelAfterMs\x18\x0f \x01(\x04\x12\x14\n\x0c\x43ollectStats\x18\x10 \x01(\x08\x12\x12\n\nLockNodeId\x18\x11 \x01(\r\"[\n\x17TCreateVolatileSnapshot\x12\x0f\n\x07OwnerId\x18\x01 \x01(\x04\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12\x0c\n\x04Name\x18\x03 \x01(\t\x12\x11\n\tTimeoutMs\x18\x04 \x01(\x04\"T\n\x15TDropVolatileSnapshot\x12\x0f\n\x07OwnerId\x18\x01 \x01(\x04\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12\x0c\n\x04Step\x18\x03 \x01(\x04\x12\x0c\n\x04TxId\x18\x04 \x01(\x04\"\xac\x01\n\x14TSnapshotTransaction\x12K\n\x16\x43reateVolatileSnapshot\x18\x01 \x01(\x0b\x32+.NKikimrTxDataShard.TCreateVolatileSnapshot\x12G\n\x14\x44ropVolatileSnapshot\x18\x02 \x01(\x0b\x32).NKikimrTxDataShard.TDropVolatileSnapshot\"\x83\x03\n\x18TSnapshotTransferReadSet\x12\x18\n\x10\x42orrowedSnapshot\x18\x01 \x01(\x0c\x12\x1b\n\x13MinWriteVersionStep\x18\x02 \x01(\x04\x12\x1b\n\x13MinWriteVersionTxId\x18\x03 \x01(\x04\x12\x1c\n\x14MvccCompleteEdgeStep\x18\x04 \x01(\x04\x12\x1c\n\x14MvccCompleteEdgeTxId\x18\x05 \x01(\x04\x12\x1e\n\x16MvccIncompleteEdgeStep\x18\x06 \x01(\x04\x12\x1e\n\x16MvccIncompleteEdgeTxId\x18\x07 \x01(\x04\x12\x1c\n\x14MvccLowWatermarkStep\x18\x08 \x01(\x04\x12\x1c\n\x14MvccLowWatermarkTxId\x18\t \x01(\x04\x12\"\n\x1aMvccImmediateWriteEdgeStep\x18\n \x01(\x04\x12\"\n\x1aMvccImmediateWriteEdgeTxId\x18\x0b \x01(\x04\x12\x13\n\x0bWithOpenTxs\x18\x0c \x01(\x08\"&\n\x15TSnapshotTransferInfo\x12\r\n\x05Shard\x18\x01 \x01(\x04\"\x9d\x01\n\x10TReceiveSnapshot\x12\x1a\n\x12TableId_Deprecated\x18\x01 \x01(\x04\x12>\n\x0bReceiveFrom\x18\x02 \x03(\x0b\x32).NKikimrTxDataShard.TSnapshotTransferInfo\x12-\n\x07TableId\x18\x03 \x01(\x0b\x32\x1c.NKikimrTxDataShard.TTableId\"\x95\x01\n\rTSendSnapshot\x12\x1a\n\x12TableId_Deprecated\x18\x01 \x01(\x04\x12\x39\n\x06SendTo\x18\x02 \x03(\x0b\x32).NKikimrTxDataShard.TSnapshotTransferInfo\x12-\n\x07TableId\x18\x03 \x01(\x0b\x32\x1c.NKikimrTxDataShard.TTableId\"3\n\x0eTSchemeOpSeqNo\x12\x12\n\nGeneration\x18\x01 \x01(\x04\x12\r\n\x05Round\x18\x02 \x01(\x04\"J\n\x19TCreatePersistentSnapshot\x12\x0f\n\x07OwnerId\x18\x01 \x01(\x04\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12\x0c\n\x04Name\x18\x03 \x01(\t\"V\n\x17TDropPersistentSnapshot\x12\x0f\n\x07OwnerId\x18\x01 \x01(\x04\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12\x0c\n\x04Step\x18\x03 \x01(\x04\x12\x0c\n\x04TxId\x18\x04 \x01(\x04\"\xac\x01\n\x13TInitiateBuildIndex\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x14\n\x0cSnapshotName\x18\x02 \x01(\t\x12\x1a\n\x12TableSchemaVersion\x18\x03 \x01(\x04\x12<\n\x10IndexDescription\x18\x04 \x01(\x0b\x32\".NKikimrSchemeOp.TIndexDescription\"\xd0\x01\n\x13TFinalizeBuildIndex\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x14\n\x0cSnapshotStep\x18\x02 \x01(\x04\x12\x14\n\x0cSnapshotTxId\x18\x03 \x01(\x04\x12\x1a\n\x12TableSchemaVersion\x18\x04 \x01(\x04\x12\x14\n\x0c\x42uildIndexId\x18\x05 \x01(\x04\x12\x34\n\x07Outcome\x18\x06 \x01(\x0b\x32#.NKikimrSchemeOp.TBuildIndexOutcome\"\x81\x01\n\x10TDropIndexNotice\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x1a\n\x12TableSchemaVersion\x18\x02 \x01(\x04\x12*\n\x0bIndexPathId\x18\x03 \x01(\x0b\x32\x15.NKikimrProto.TPathID\"\xb4\x01\n\x16TCreateCdcStreamNotice\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x1a\n\x12TableSchemaVersion\x18\x02 \x01(\x04\x12\x41\n\x11StreamDescription\x18\x03 \x01(\x0b\x32&.NKikimrSchemeOp.TCdcStreamDescription\x12\x14\n\x0cSnapshotName\x18\x04 \x01(\t\"\x9d\x01\n\x15TAlterCdcStreamNotice\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x1a\n\x12TableSchemaVersion\x18\x02 \x01(\x04\x12\x41\n\x11StreamDescription\x18\x03 \x01(\x0b\x32&.NKikimrSchemeOp.TCdcStreamDescription\"\x86\x01\n\x14TDropCdcStreamNotice\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x1a\n\x12TableSchemaVersion\x18\x02 \x01(\x04\x12+\n\x0cStreamPathId\x18\x03 \x01(\x0b\x32\x15.NKikimrProto.TPathID\"\x11\n\x0fTAsyncIndexInfo\"\xa7\x01\n\x11TRemapIndexPathId\x12(\n\tSrcPathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12(\n\tDstPathId\x18\x02 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12-\n\x0eReplacedPathId\x18\x03 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x0f\n\x07\x44stName\x18\x04 \x01(\t\"\xc7\x01\n\nTMoveTable\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x1a\n\x12TableSchemaVersion\x18\x02 \x01(\x04\x12(\n\tDstPathId\x18\x03 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x0f\n\x07\x44stPath\x18\x04 \x01(\t\x12;\n\x0cReMapIndexes\x18\x05 \x03(\x0b\x32%.NKikimrTxDataShard.TRemapIndexPathId\"\x8a\x01\n\nTMoveIndex\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x1a\n\x12TableSchemaVersion\x18\x02 \x01(\x04\x12\x39\n\nReMapIndex\x18\x03 \x01(\x0b\x32%.NKikimrTxDataShard.TRemapIndexPathId\"\xc6\t\n\x16TFlatSchemeTransaction\x12\x37\n\x0b\x43reateTable\x18\x01 \x01(\x0b\x32\".NKikimrSchemeOp.TTableDescription\x12\x35\n\tDropTable\x18\x02 \x01(\x0b\x32\".NKikimrSchemeOp.TTableDescription\x12\x36\n\nAlterTable\x18\x03 \x01(\x0b\x32\".NKikimrSchemeOp.TTableDescription\x12=\n\x0fReceiveSnapshot\x18\x04 \x01(\x0b\x32$.NKikimrTxDataShard.TReceiveSnapshot\x12\x37\n\x0cSendSnapshot\x18\x05 \x01(\x0b\x32!.NKikimrTxDataShard.TSendSnapshot\x12,\n\x06\x42\x61\x63kup\x18\x06 \x01(\x0b\x32\x1c.NKikimrSchemeOp.TBackupTask\x12\x31\n\x05SeqNo\x18\x07 \x01(\x0b\x32\".NKikimrTxDataShard.TSchemeOpSeqNo\x12\x10\n\x08ReadOnly\x18\x08 \x01(\x08\x12O\n\x18\x43reatePersistentSnapshot\x18\n \x01(\x0b\x32-.NKikimrTxDataShard.TCreatePersistentSnapshot\x12K\n\x16\x44ropPersistentSnapshot\x18\x0b \x01(\x0b\x32+.NKikimrTxDataShard.TDropPersistentSnapshot\x12\x43\n\x12InitiateBuildIndex\x18\x0c \x01(\x0b\x32\'.NKikimrTxDataShard.TInitiateBuildIndex\x12\x43\n\x12\x46inalizeBuildIndex\x18\r \x01(\x0b\x32\'.NKikimrTxDataShard.TFinalizeBuildIndex\x12=\n\x0f\x44ropIndexNotice\x18\x0e \x01(\x0b\x32$.NKikimrTxDataShard.TDropIndexNotice\x12.\n\x07Restore\x18\x0f \x01(\x0b\x32\x1d.NKikimrSchemeOp.TRestoreTask\x12;\n\x0e\x41syncIndexInfo\x18\x10 \x01(\x0b\x32#.NKikimrTxDataShard.TAsyncIndexInfo\x12\x31\n\tMoveTable\x18\x11 \x01(\x0b\x32\x1e.NKikimrTxDataShard.TMoveTable\x12I\n\x15\x43reateCdcStreamNotice\x18\x12 \x01(\x0b\x32*.NKikimrTxDataShard.TCreateCdcStreamNotice\x12G\n\x14\x41lterCdcStreamNotice\x18\x13 \x01(\x0b\x32).NKikimrTxDataShard.TAlterCdcStreamNotice\x12\x45\n\x13\x44ropCdcStreamNotice\x18\x14 \x01(\x0b\x32(.NKikimrTxDataShard.TDropCdcStreamNotice\x12\x31\n\tMoveIndex\x18\x15 \x01(\x0b\x32\x1e.NKikimrTxDataShard.TMoveIndexJ\x04\x08\t\x10\n\"\x88\x03\n\x1cTDistributedEraseTransaction\x12\x41\n\x10\x45raseRowsRequest\x18\x01 \x01(\x0b\x32\'.NKikimrTxDataShard.TEvEraseRowsRequest\x12O\n\nDependents\x18\x02 \x03(\x0b\x32;.NKikimrTxDataShard.TDistributedEraseTransaction.TDependent\x12R\n\x0c\x44\x65pendencies\x18\x03 \x03(\x0b\x32<.NKikimrTxDataShard.TDistributedEraseTransaction.TDependency\x12\x16\n\x0eIndexColumnIds\x18\x04 \x03(\r\x12\x14\n\x0cIndexColumns\x18\x05 \x03(\x0c\x1a\x1d\n\nTDependent\x12\x0f\n\x07ShardId\x18\x01 \x01(\x04\x1a\x33\n\x0bTDependency\x12\x0f\n\x07ShardId\x18\x01 \x01(\x04\x12\x13\n\x0bPresentRows\x18\x02 \x01(\x0c\",\n\x13TDistributedEraseRS\x12\x15\n\rConfirmedRows\x18\x01 \x01(\x0c\"\\\n\x18TCommitWritesTransaction\x12-\n\x07TableId\x18\x01 \x01(\x0b\x32\x1c.NKikimrTxDataShard.TTableId\x12\x11\n\tWriteTxId\x18\x02 \x01(\x04\"+\n\rTMvccSnapshot\x12\x0c\n\x04Step\x18\n \x01(\x04\x12\x0c\n\x04TxId\x18\x0b \x01(\x04\"\xde\x02\n\x15TEvProposeTransaction\x12\x34\n\x06TxKind\x18\x01 \x01(\x0e\x32$.NKikimrTxDataShard.ETransactionKind\x12&\n\x06Source\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x0e\n\x06TxBody\x18\x03 \x01(\x0c\x12\x0c\n\x04TxId\x18\x04 \x01(\x04\x12\x11\n\tExecLevel\x18\x05 \x01(\r\x12\r\n\x05\x46lags\x18\x06 \x01(\r\x12\x15\n\rSchemeShardId\x18\x07 \x01(\x04\x12>\n\x10ProcessingParams\x18\x08 \x01(\x0b\x32$.NKikimrSubDomains.TProcessingParams\x12\x17\n\x0fSubDomainPathId\x18\t \x01(\x04\x12\x37\n\x0cMvccSnapshot\x18\n \x01(\x0b\x32!.NKikimrTxDataShard.TMvccSnapshot\",\n\x1cTEvCancelTransactionProposal\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\"\x84\x04\n\x06TError\x12.\n\x04Kind\x18\x01 \x01(\x0e\x32 .NKikimrTxDataShard.TError.EKind\x12\x0b\n\x03Key\x18\x02 \x01(\x0c\x12\x0e\n\x06Reason\x18\x03 \x01(\x0c\"\xac\x03\n\x05\x45Kind\x12\x06\n\x02OK\x10\x00\x12\x0f\n\x0b\x42\x41\x44_TX_KIND\x10\x01\x12\x10\n\x0c\x42\x41\x44_ARGUMENT\x10\x02\x12\x10\n\x0cSCHEME_ERROR\x10\x03\x12\x16\n\x12WRONG_PAYLOAD_TYPE\x10\x04\x12\x11\n\rLEAF_REQUIRED\x10\x05\x12\x0c\n\x08READONLY\x10\x06\x12\x15\n\x11WRONG_SHARD_STATE\x10\x07\x12\x16\n\x12SNAPSHOT_NOT_EXIST\x10\x08\x12\x1a\n\x16SNAPSHOT_NOT_READY_YET\x10\t\x12\x12\n\x0eSCHEME_CHANGED\x10\n\x12\x1e\n\x1a\x44UPLICATED_SNAPSHOT_POLICY\x10\x0b\x12\x1b\n\x17MISSING_SNAPSHOT_POLICY\x10\x0c\x12\x11\n\rPROGRAM_ERROR\x10\r\x12\x10\n\x0cOUT_OF_SPACE\x10\x0e\x12\x17\n\x13READ_SIZE_EXECEEDED\x10\x0f\x12\x14\n\x10SHARD_IS_BLOCKED\x10\x10\x12\x0b\n\x07UNKNOWN\x10\x11\x12\x17\n\x13REPLY_SIZE_EXCEEDED\x10\x12\x12\x17\n\x13\x45XECUTION_CANCELLED\x10\x13\"t\n\x05TLock\x12\x0e\n\x06LockId\x18\x01 \x01(\x06\x12\x11\n\tDataShard\x18\x02 \x01(\x06\x12\x12\n\nGeneration\x18\x03 \x01(\r\x12\x0f\n\x07\x43ounter\x18\x04 \x01(\x04\x12\x13\n\x0bSchemeShard\x18\x05 \x01(\x06\x12\x0e\n\x06PathId\x18\x06 \x01(\x04\"~\n\x0bTTabletInfo\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12\x0c\n\x04Step\x18\x03 \x01(\x04\x12\'\n\x07\x41\x63torId\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x12\n\nIsFollower\x18\x05 \x01(\x08\"\xf4\x08\n\x1bTEvProposeTransactionResult\x12\x34\n\x06TxKind\x18\x01 \x01(\x0e\x32$.NKikimrTxDataShard.ETransactionKind\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12G\n\x06Status\x18\x03 \x01(\x0e\x32\x37.NKikimrTxDataShard.TEvProposeTransactionResult.EStatus\x12)\n\x05\x45rror\x18\x04 \x03(\x0b\x32\x1a.NKikimrTxDataShard.TError\x12\x0c\n\x04TxId\x18\x05 \x01(\x04\x12\x0f\n\x07MinStep\x18\x06 \x01(\x04\x12\x0f\n\x07MaxStep\x18\x07 \x01(\x04\x12\x10\n\x08TxResult\x18\x08 \x01(\x0c\x12\x0c\n\x04Step\x18\t \x01(\x04\x12\x0f\n\x07OrderId\x18\n \x01(\x04\x12\x36\n\x10\x42\x61lanceTrackList\x18\x0b \x01(\x0b\x32\x1c.NKikimrTx.TBalanceTrackList\x12\x19\n\x11PrepareArriveTime\x18\x0c \x01(\x04\x12\x13\n\x0b\x45xecLatency\x18\r \x01(\x04\x12\x16\n\x0eProposeLatency\x18\x0e \x01(\x04\x12*\n\x07TxLocks\x18\x0f \x03(\x0b\x32\x19.NKikimrTxDataShard.TLock\x12\x10\n\x08ReadSize\x18\x10 \x01(\x04\x12\x11\n\tReplySize\x18\x11 \x01(\x04\x12Y\n\x13OutgoingReadSetInfo\x18\x12 \x03(\x0b\x32<.NKikimrTxDataShard.TEvProposeTransactionResult.TReadSetInfo\x12\x33\n\nTabletInfo\x18\x13 \x01(\x0b\x32\x1f.NKikimrTxDataShard.TTabletInfo\x12\x12\n\nRowOffsets\x18\x14 \x03(\r\x12\x1a\n\x12\x44omainCoordinators\x18\x15 \x03(\x06\x12\x12\n\nApiVersion\x18\x16 \x01(\r\x12,\n\x07TxStats\x18\x17 \x01(\x0b\x32\x1b.NKikimrQueryStats.TTxStats\x12\x11\n\tDataSeqNo\x18\x18 \x01(\x04\x12\x13\n\x0b\x44\x61taLastKey\x18\x19 \x01(\x0c\x12>\n\x11\x43omputeActorStats\x18\x1b \x01(\x0b\x32#.NYql.NDqProto.TDqComputeActorStats\x1a-\n\x0cTReadSetInfo\x12\x0f\n\x07ShardId\x18\x01 \x01(\x04\x12\x0c\n\x04Size\x18\x02 \x01(\x04\"\xc9\x01\n\x07\x45Status\x12\x0c\n\x08PREPARED\x10\x01\x12\x0c\n\x08\x43OMPLETE\x10\x02\x12\x0b\n\x07\x41\x42ORTED\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\r\n\tTRY_LATER\x10\x05\x12\x0e\n\nOVERLOADED\x10\x06\x12\x11\n\rRESPONSE_DATA\x10\x07\x12\x0e\n\nEXEC_ERROR\x10\x08\x12\x16\n\x12RESULT_UNAVAILABLE\x10\t\x12\x10\n\x0cLOCKS_BROKEN\x10\n\x12\r\n\tCANCELLED\x10\x0b\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x0cJ\x04\x08\x1a\x10\x1b\">\n\x1cTEvProposeTransactionRestart\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\"=\n\x1bTEvProposeTransactionAttach\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\"o\n!TEvProposeTransactionAttachResult\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12*\n\x06Status\x18\x03 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\"a\n\x1dTAddSnapshotPolicyTransaction\x12\x1a\n\x12SnapshotCountLimit\x18\x01 \x01(\r\x12\x11\n\tStartStep\x18\x02 \x01(\x04\x12\x11\n\tDeltaStep\x18\x03 \x01(\x04\"^\n\x15TEvReturnBorrowedPart\x12\x14\n\x0c\x46romTabletId\x18\x01 \x01(\x04\x12/\n\x0cPartMetadata\x18\x02 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\"K\n\x18TEvReturnBorrowedPartAck\x12/\n\x0cPartMetadata\x18\x01 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\"c\n\x11TKeyRangeToTablet\x12\x15\n\rKeyRangeBegin\x18\x01 \x01(\x0c\x12\x13\n\x0bKeyRangeEnd\x18\x02 \x01(\x0c\x12\x10\n\x08TabletID\x18\x03 \x01(\x04\x12\x10\n\x08ShardIdx\x18\x04 \x01(\x04\"\x97\x01\n\x16TSplitMergeDescription\x12;\n\x0cSourceRanges\x18\x01 \x03(\x0b\x32%.NKikimrTxDataShard.TKeyRangeToTablet\x12@\n\x11\x44\x65stinationRanges\x18\x02 \x03(\x0b\x32%.NKikimrTxDataShard.TKeyRangeToTablet\"\xac\x02\n\x1cTEvInitSplitMergeDestination\x12\x17\n\x0fOperationCookie\x18\x01 \x01(\x04\x12\x1b\n\x13SchemeshardTabletId\x18\x02 \x01(\x04\x12\x44\n\x10SplitDescription\x18\x03 \x01(\x0b\x32*.NKikimrTxDataShard.TSplitMergeDescription\x12>\n\x10ProcessingParams\x18\x04 \x01(\x0b\x32$.NKikimrSubDomains.TProcessingParams\x12\x37\n\x0b\x43reateTable\x18\x05 \x01(\x0b\x32\".NKikimrSchemeOp.TTableDescription\x12\x17\n\x0fSubDomainPathId\x18\x06 \x01(\x04\"L\n\x1fTEvInitSplitMergeDestinationAck\x12\x17\n\x0fOperationCookie\x18\x01 \x01(\x04\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\"i\n\x08TEvSplit\x12\x17\n\x0fOperationCookie\x18\x01 \x01(\x04\x12\x44\n\x10SplitDescription\x18\x02 \x01(\x0b\x32*.NKikimrTxDataShard.TSplitMergeDescription\"8\n\x0bTEvSplitAck\x12\x17\n\x0fOperationCookie\x18\x01 \x01(\x04\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\"7\n\x0eTTableSnapshot\x12\x0f\n\x07TableId\x18\x01 \x01(\x04\x12\x14\n\x0cSnapshotData\x18\x02 \x01(\x0c\"\x82\x01\n\x13TPersistentSnapshot\x12\x0f\n\x07OwnerId\x18\x01 \x01(\x04\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12\x0c\n\x04Step\x18\x03 \x01(\x04\x12\x0c\n\x04TxId\x18\x04 \x01(\x04\x12\x0c\n\x04Name\x18\x05 \x01(\t\x12\r\n\x05\x46lags\x18\x06 \x01(\x04\x12\x11\n\tTimeoutMs\x18\x07 \x01(\x04\"\xc6\x05\n\x18TEvSplitTransferSnapshot\x12\x17\n\x0fOperationCookie\x18\x01 \x01(\x04\x12\x13\n\x0bSrcTabletId\x18\x02 \x01(\x04\x12;\n\x0fUserTableScheme\x18\x03 \x01(\x0b\x32\".NKikimrSchemeOp.TTableDescription\x12\x39\n\rTableSnapshot\x18\x04 \x03(\x0b\x32\".NKikimrTxDataShard.TTableSnapshot\x12\x1b\n\x13MinWriteVersionStep\x18\x05 \x01(\x04\x12\x1b\n\x13MinWriteVersionTxId\x18\x06 \x01(\x04\x12\x44\n\x13PersistentSnapshots\x18\x07 \x03(\x0b\x32\'.NKikimrTxDataShard.TPersistentSnapshot\x12\x1c\n\x14MvccCompleteEdgeStep\x18\x08 \x01(\x04\x12\x1c\n\x14MvccCompleteEdgeTxId\x18\t \x01(\x04\x12\x1e\n\x16MvccIncompleteEdgeStep\x18\n \x01(\x04\x12\x1e\n\x16MvccIncompleteEdgeTxId\x18\x0b \x01(\x04\x12\x1c\n\x14MvccLowWatermarkStep\x18\x0c \x01(\x04\x12\x1c\n\x14MvccLowWatermarkTxId\x18\r \x01(\x04\x12\x19\n\x11WaitForActivation\x18\x0e \x01(\x08\x12\x1b\n\x13SrcTabletGeneration\x18\x0f \x01(\x04\x12%\n\x1dReplicationSourceOffsetsBytes\x18\x10 \x01(\x04\x12\"\n\x1aMvccImmediateWriteEdgeStep\x18\x11 \x01(\x04\x12\"\n\x1aMvccImmediateWriteEdgeTxId\x18\x12 \x01(\x04\x12%\n\x1dMvccPerformedUnprotectedReads\x18\x13 \x01(\x08\"H\n\x1bTEvSplitTransferSnapshotAck\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x17\n\x0fOperationCookie\x18\x02 \x01(\x04\"^\n\x1bTEvSplitPartitioningChanged\x12&\n\x06Sender\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x17\n\x0fOperationCookie\x18\x01 \x01(\x04\"K\n\x1eTEvSplitPartitioningChangedAck\x12\x17\n\x0fOperationCookie\x18\x01 \x01(\x04\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\"6\n\x0fTEvCancelBackup\x12\x12\n\nBackupTxId\x18\x01 \x01(\x04\x12\x0f\n\x07TableId\x18\x02 \x01(\x04\"8\n\x10TEvCancelRestore\x12\x13\n\x0bRestoreTxId\x18\x01 \x01(\x04\x12\x0f\n\x07TableId\x18\x02 \x01(\x04\"u\n\x10TEvGetTableStats\x12\x0f\n\x07TableId\x18\x01 \x01(\x04\x12\x1a\n\x12\x44\x61taSizeResolution\x18\x02 \x01(\x04\x12\x1a\n\x12RowCountResolution\x18\x03 \x01(\x04\x12\x18\n\x10\x43ollectKeySample\x18\x04 \x01(\x08\"\xa7\x02\n\x16TEvGetTableStatsResult\x12\x13\n\x0b\x44\x61tashardId\x18\x01 \x01(\x04\x12\x14\n\x0cTableLocalId\x18\x02 \x01(\x04\x12\x32\n\nTableStats\x18\x03 \x01(\x0b\x32\x1e.NKikimrTableStats.TTableStats\x12\x32\n\rTabletMetrics\x18\x04 \x01(\x0b\x32\x1b.NKikimrTabletBase.TMetrics\x12\x12\n\nShardState\x18\x05 \x01(\r\x12\x1b\n\x13UserTablePartOwners\x18\x06 \x03(\x04\x12\x1b\n\x13SysTablesPartOwners\x18\x07 \x03(\x04\x12\x16\n\x0e\x46ullStatsReady\x18\x08 \x01(\x08\x12\x14\n\x0cTableOwnerId\x18\t \x01(\x04\"\xe8\x02\n\x15TEvPeriodicTableStats\x12\x13\n\x0b\x44\x61tashardId\x18\x01 \x01(\x04\x12\x14\n\x0cTableLocalId\x18\x02 \x01(\x04\x12\x12\n\nGeneration\x18\x03 \x01(\x04\x12\r\n\x05Round\x18\x04 \x01(\x04\x12\x32\n\nTableStats\x18\x05 \x01(\x0b\x32\x1e.NKikimrTableStats.TTableStats\x12\x32\n\rTabletMetrics\x18\x06 \x01(\x0b\x32\x1b.NKikimrTabletBase.TMetrics\x12\x12\n\nShardState\x18\x07 \x01(\r\x12\x1b\n\x13UserTablePartOwners\x18\x08 \x03(\x04\x12\x1b\n\x13SysTablesPartOwners\x18\t \x03(\x04\x12\x0e\n\x06NodeId\x18\n \x01(\r\x12\x11\n\tStartTime\x18\x0b \x01(\x04\x12\x14\n\x0cTableOwnerId\x18\x0c \x01(\x04\x12\x12\n\nIsDstSplit\x18\r \x01(\x08\"K\n\x1bTSerializedRowColumnsScheme\x12\x14\n\x0cKeyColumnIds\x18\x01 \x03(\r\x12\x16\n\x0eValueColumnIds\x18\x02 \x03(\r\"@\n\x14TSerializedRowToLoad\x12\x12\n\nKeyColumns\x18\x01 \x01(\x0c\x12\x14\n\x0cValueColumns\x18\x02 \x01(\x0c\"\xd9\x01\n\x14TEvUploadRowsRequest\x12\x0f\n\x07TableId\x18\x01 \x01(\x04\x12\x42\n\tRowScheme\x18\x02 \x01(\x0b\x32/.NKikimrTxDataShard.TSerializedRowColumnsScheme\x12\x36\n\x04Rows\x18\x03 \x03(\x0b\x32(.NKikimrTxDataShard.TSerializedRowToLoad\x12\x18\n\x10\x43\x61ncelDeadlineMs\x18\x04 \x01(\x04\x12\x1a\n\x12WriteToTableShadow\x18\x05 \x01(\x08\"S\n\x15TEvUploadRowsResponse\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\x12\x0e\n\x06Status\x18\x02 \x01(\r\x12\x18\n\x10\x45rrorDescription\x18\x03 \x01(\t\"\xc3\x01\n\x15TEvReadColumnsRequest\x12\x0f\n\x07TableId\x18\x01 \x01(\x04\x12\x0f\n\x07\x43olumns\x18\x02 \x03(\t\x12\x0f\n\x07MaxRows\x18\x03 \x01(\x04\x12\x10\n\x08MaxBytes\x18\x04 \x01(\x04\x12\x0f\n\x07\x46romKey\x18\x05 \x01(\x0c\x12\x18\n\x10\x46romKeyInclusive\x18\x06 \x01(\x08\x12\x14\n\x0cSnapshotStep\x18\x07 \x01(\x04\x12\x14\n\x0cSnapshotTxId\x18\x08 \x01(\x04\x12\x0e\n\x06\x46ormat\x18\t \x01(\t\"\xa3\x01\n\x16TEvReadColumnsResponse\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\x12\x0e\n\x06Status\x18\x02 \x01(\r\x12\x18\n\x10\x45rrorDescription\x18\x03 \x01(\t\x12\x0e\n\x06\x42locks\x18\x04 \x01(\x0c\x12\x0f\n\x07LastKey\x18\x05 \x01(\x0c\x12\x18\n\x10LastKeyInclusive\x18\x06 \x01(\x08\x12\x12\n\nEndOfShard\x18\x07 \x01(\x08\"[\n\x07TStatus\x12\'\n\x04\x43ode\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"\x13\n\x11TEvGetInfoRequest\"\xe5\r\n\x12TEvGetInfoResponse\x12+\n\x06Status\x18\x01 \x01(\x0b\x32\x1b.NKikimrTxDataShard.TStatus\x12\x45\n\nUserTables\x18\x02 \x03(\x0b\x32\x31.NKikimrTxDataShard.TEvGetInfoResponse.TUserTable\x12\x46\n\nTabletInfo\x18\x03 \x01(\x0b\x32\x32.NKikimrTxDataShard.TEvGetInfoResponse.TTabletInfo\x12\x44\n\x08\x43ontrols\x18\x04 \x03(\x0b\x32\x32.NKikimrTxDataShard.TEvGetInfoResponse.TNamedValue\x12\x46\n\nActivities\x18\x05 \x01(\x0b\x32\x32.NKikimrTxDataShard.TEvGetInfoResponse.TActivities\x12\x44\n\x08SysTable\x18\x06 \x03(\x0b\x32\x32.NKikimrTxDataShard.TEvGetInfoResponse.TNamedValue\x12N\n\x0ePipelineConfig\x18\x07 \x01(\x0b\x32\x36.NKikimrTxDataShard.TEvGetInfoResponse.TPipelineConfig\x1a\x96\x01\n\x06TStats\x12\x10\n\x08RowCount\x18\x01 \x01(\x04\x12\x10\n\x08\x44\x61taSize\x18\x02 \x01(\x04\x12\x16\n\x0eLastAccessTime\x18\x03 \x01(\t\x12\x16\n\x0eLastUpdateTime\x18\x04 \x01(\t\x12\x1b\n\x13LastStatsUpdateTime\x18\x05 \x01(\t\x12\x1b\n\x13LastStatsReportTime\x18\x06 \x01(\t\x1a\x85\x02\n\nTUserTable\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0c\n\x04Path\x18\x02 \x01(\t\x12\x0f\n\x07LocalId\x18\x03 \x01(\r\x12\x0e\n\x06PathId\x18\x04 \x01(\x04\x12\x37\n\x0b\x44\x65scription\x18\x05 \x01(\x0b\x32\".NKikimrSchemeOp.TTableDescription\x12<\n\x05Stats\x18\x06 \x01(\x0b\x32-.NKikimrTxDataShard.TEvGetInfoResponse.TStats\x12,\n\x07Metrics\x18\x07 \x01(\x0b\x32\x1b.NKikimrTabletBase.TMetrics\x12\x15\n\rSchemaVersion\x18\x08 \x01(\x04\x1a\x95\x01\n\x0bTTabletInfo\x12\x13\n\x0bSchemeShard\x18\x01 \x01(\x04\x12\x10\n\x08Mediator\x18\x02 \x01(\x04\x12\x12\n\nGeneration\x18\x03 \x01(\r\x12\x12\n\nIsFollower\x18\x04 \x01(\x08\x12\r\n\x05State\x18\x05 \x01(\t\x12\x10\n\x08IsActive\x18\x06 \x01(\x08\x12\x16\n\x0eHasSharedBlobs\x18\x07 \x01(\x08\x1a*\n\x0bTNamedValue\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\t\x1a\xcd\x03\n\x0bTActivities\x12\x14\n\x0cInFlyPlanned\x18\x01 \x01(\x04\x12\x16\n\x0eInFlyImmediate\x18\x02 \x01(\x04\x12\x14\n\x0c\x45xecutingOps\x18\x03 \x01(\x04\x12\x12\n\nWaitingOps\x18\x04 \x01(\x04\x12\x17\n\x0f\x45xecuteBlockers\x18\x05 \x01(\x04\x12\x14\n\x0c\x44\x61taTxCached\x18\x06 \x01(\x04\x12\x13\n\x0bOutReadSets\x18\x07 \x01(\x04\x12\x17\n\x0fOutReadSetsAcks\x18\x08 \x01(\x04\x12\x13\n\x0b\x44\x65layedAcks\x18\t \x01(\x04\x12\r\n\x05Locks\x18\n \x01(\x04\x12\x13\n\x0b\x42rokenLocks\x18\x0b \x01(\x04\x12\x15\n\rLastPlannedTx\x18\x0c \x01(\x04\x12\x17\n\x0fLastPlannedStep\x18\r \x01(\x04\x12\x17\n\x0fLastCompletedTx\x18\x0e \x01(\x04\x12\x19\n\x11LastCompletedStep\x18\x0f \x01(\x04\x12\x19\n\x11UtmostCompletedTx\x18\x10 \x01(\x04\x12\x1b\n\x13UtmostCompletedStep\x18\x11 \x01(\x04\x12\x19\n\x11\x44\x61taTxCompleteLag\x18\x12 \x01(\x04\x12\x19\n\x11ScanTxCompleteLag\x18\x13 \x01(\x04\x1a\xb9\x01\n\x0fTPipelineConfig\x12\x19\n\x11OutOfOrderEnabled\x18\x01 \x01(\x08\x12\x16\n\x0e\x41\x63tiveTxsLimit\x18\x02 \x01(\r\x12\x16\n\x0e\x41llowImmediate\x18\x03 \x01(\x08\x12\x15\n\rForceOnlineRW\x18\x04 \x01(\x08\x12\x13\n\x0b\x44irtyOnline\x18\x05 \x01(\x08\x12\x16\n\x0e\x44irtyImmediate\x18\x06 \x01(\x08\x12\x17\n\x0f\x44\x61taTxCacheSize\x18\x07 \x01(\r\"\x1a\n\x18TEvListOperationsRequest\"\xe8\x02\n\x19TEvListOperationsResponse\x12+\n\x06Status\x18\x01 \x01(\x0b\x32\x1b.NKikimrTxDataShard.TStatus\x12P\n\nOperations\x18\x02 \x03(\x0b\x32<.NKikimrTxDataShard.TEvListOperationsResponse.TOperationInfo\x1a\xcb\x01\n\x0eTOperationInfo\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0c\n\x04Step\x18\x02 \x01(\x04\x12\x0c\n\x04Kind\x18\x03 \x01(\t\x12\x13\n\x0bIsImmediate\x18\x04 \x01(\x08\x12\x12\n\nIsReadOnly\x18\x05 \x01(\x08\x12\x11\n\tIsWaiting\x18\x06 \x01(\x08\x12\x13\n\x0bIsExecuting\x18\x07 \x01(\x08\x12\x13\n\x0bIsCompleted\x18\x08 \x01(\x08\x12\x15\n\rExecutionUnit\x18\t \x01(\t\x12\x12\n\nReceivedAt\x18\n \x01(\x04\"&\n\x16TEvGetOperationRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\"}\n\x0cTBasicOpInfo\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0c\n\x04Step\x18\x02 \x01(\x04\x12\x0c\n\x04Kind\x18\x03 \x01(\t\x12\x12\n\nReceivedAt\x18\x04 \x01(\x04\x12\x0f\n\x07MinStep\x18\x05 \x01(\x04\x12\x0f\n\x07MaxStep\x18\x06 \x01(\x04\x12\r\n\x05\x46lags\x18\x07 \x03(\t\"\xe7\x01\n\x11TExecutionProfile\x12H\n\x0cUnitProfiles\x18\x01 \x03(\x0b\x32\x32.NKikimrTxDataShard.TExecutionProfile.TUnitProfile\x1a\x87\x01\n\x0cTUnitProfile\x12\x10\n\x08UnitKind\x18\x01 \x01(\t\x12\x10\n\x08WaitTime\x18\x02 \x01(\x04\x12\x13\n\x0b\x45xecuteTime\x18\x03 \x01(\x04\x12\x12\n\nCommitTime\x18\x04 \x01(\x04\x12\x14\n\x0c\x43ompleteTime\x18\x05 \x01(\x04\x12\x14\n\x0c\x45xecuteCount\x18\x06 \x01(\r\"\xc1\x08\n\x17TEvGetOperationResponse\x12+\n\x06Status\x18\x01 \x01(\x0b\x32\x1b.NKikimrTxDataShard.TStatus\x12\x33\n\tBasicInfo\x18\x02 \x01(\x0b\x32 .NKikimrTxDataShard.TBasicOpInfo\x12Q\n\rExecutionPlan\x18\x03 \x01(\x0b\x32:.NKikimrTxDataShard.TEvGetOperationResponse.TExecutionPlan\x12O\n\x0c\x44\x65pendencies\x18\x04 \x01(\x0b\x32\x39.NKikimrTxDataShard.TEvGetOperationResponse.TDependencies\x12I\n\tInputData\x18\x05 \x01(\x0b\x32\x36.NKikimrTxDataShard.TEvGetOperationResponse.TInputData\x12?\n\x10\x45xecutionProfile\x18\x06 \x01(\x0b\x32%.NKikimrTxDataShard.TExecutionProfile\x12S\n\x0eReadTableState\x18\n \x01(\x0b\x32;.NKikimrTxDataShard.TEvGetOperationResponse.TReadTableState\x1aH\n\x0eTExecutionPlan\x12\r\n\x05Units\x18\x01 \x03(\t\x12\x12\n\nIsFinished\x18\x02 \x01(\x08\x12\x13\n\x0b\x43urrentUnit\x18\x03 \x01(\r\x1a,\n\x0bTDependency\x12\x0e\n\x06Target\x18\x01 \x01(\x04\x12\r\n\x05Types\x18\x02 \x03(\t\x1a\xab\x01\n\rTDependencies\x12M\n\x0c\x44\x65pendencies\x18\x01 \x03(\x0b\x32\x37.NKikimrTxDataShard.TEvGetOperationResponse.TDependency\x12K\n\nDependents\x18\x02 \x03(\x0b\x32\x37.NKikimrTxDataShard.TEvGetOperationResponse.TDependency\x1a*\n\x08TInputRS\x12\x0c\n\x04\x46rom\x18\x01 \x01(\x04\x12\x10\n\x08Received\x18\x02 \x01(\r\x1al\n\nTInputData\x12\x45\n\x07InputRS\x18\x01 \x03(\x0b\x32\x34.NKikimrTxDataShard.TEvGetOperationResponse.TInputRS\x12\x17\n\x0fRemainedInputRS\x18\x02 \x01(\r\x1a\x7f\n\x0fTReadTableState\x12\r\n\x05State\x18\x01 \x01(\t\x12\x0f\n\x07TableId\x18\x02 \x01(\r\x12\x12\n\nSnapshotId\x18\x03 \x01(\x04\x12\x12\n\nScanTaskId\x18\x04 \x01(\x04\x12\x11\n\tSinkActor\x18\x05 \x01(\t\x12\x11\n\tScanActor\x18\x06 \x01(\t\"/\n\x1fTEvGetReadTableSinkStateRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\"\x14\n\x06TShard\x12\n\n\x02Id\x18\x01 \x01(\x04\"\xf3\x04\n TEvGetReadTableSinkStateResponse\x12+\n\x06Status\x18\x01 \x01(\x0b\x32\x1b.NKikimrTxDataShard.TStatus\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x19\n\x11WallClockAccepted\x18\x03 \x01(\x04\x12\x1f\n\x17WallClockResolveStarted\x18\x04 \x01(\x04\x12\x19\n\x11WallClockResolved\x18\x05 \x01(\x04\x12\x19\n\x11WallClockPrepared\x18\x06 \x01(\x04\x12\x18\n\x10WallClockPlanned\x18\x07 \x01(\x04\x12\x19\n\x11\x45xecTimeoutPeriod\x18\x08 \x01(\x04\x12\x1b\n\x13SelectedCoordinator\x18\t \x01(\x04\x12\x15\n\rRequestSource\x18\n \x01(\t\x12\x16\n\x0eRequestVersion\x18\x0b \x01(\r\x12\x17\n\x0fResponseVersion\x18\x0c \x01(\r\x12\x35\n\x11\x43learanceRequests\x18\r \x03(\x0b\x32\x1a.NKikimrTxDataShard.TShard\x12\x31\n\rQuotaRequests\x18\x0e \x03(\x0b\x32\x1a.NKikimrTxDataShard.TShard\x12\x33\n\x0fStreamingShards\x18\x0f \x03(\x0b\x32\x1a.NKikimrTxDataShard.TShard\x12/\n\x0bShardsQueue\x18\x10 \x03(\x0b\x32\x1a.NKikimrTxDataShard.TShard\x12\x0f\n\x07Ordered\x18\x11 \x01(\x08\x12\x13\n\x0bRowsLimited\x18\x12 \x01(\x08\x12\x12\n\nRowsRemain\x18\x13 \x01(\x04\"/\n\x1fTEvGetReadTableScanStateRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\"\x96\x02\n TEvGetReadTableScanStateResponse\x12+\n\x06Status\x18\x01 \x01(\x0b\x32\x1b.NKikimrTxDataShard.TStatus\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x14\n\x0cMessageQuota\x18\x03 \x01(\x04\x12\x18\n\x10MessageSizeLimit\x18\x04 \x01(\x04\x12\x11\n\tRowsLimit\x18\x05 \x01(\x04\x12\x13\n\x0bPendingAcks\x18\x06 \x01(\x04\x12\x12\n\nResultSize\x18\x07 \x01(\x04\x12\x12\n\nResultRows\x18\x08 \x01(\x04\x12\x16\n\x0eHasUpperBorder\x18\t \x01(\x08\x12\x10\n\x08\x46inished\x18\n \x01(\x08\x12\r\n\x05\x45rror\x18\x0b \x01(\t\"1\n!TEvGetReadTableStreamStateRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\"\xa3\x04\n\"TEvGetReadTableStreamStateResponse\x12+\n\x06Status\x18\x01 \x01(\x0b\x32\x1b.NKikimrTxDataShard.TStatus\x12\r\n\x05Ready\x18\x02 \x01(\x08\x12\x10\n\x08\x46inished\x18\x03 \x01(\x08\x12\x19\n\x11ResponseQueueSize\x18\x04 \x01(\x04\x12\x31\n\rQuotaRequests\x18\x05 \x03(\x0b\x32\x1a.NKikimrTxDataShard.TShard\x12W\n\x0bShardQuotas\x18\x06 \x03(\x0b\x32\x42.NKikimrTxDataShard.TEvGetReadTableStreamStateResponse.TShardQuota\x12\x12\n\nQuotaLimit\x18\x07 \x01(\x04\x12\x15\n\rQuotaReserved\x18\x08 \x01(\x04\x12\x32\n\x0eReleasedShards\x18\t \x03(\x0b\x32\x1a.NKikimrTxDataShard.TShard\x12\x1d\n\x15InactiveClientTimeout\x18\n \x01(\x04\x12\x1d\n\x15InactiveServerTimeout\x18\x0b \x01(\x04\x12\x1f\n\x17LastDataStreamTimestamp\x18\x0c \x01(\x04\x12\x1b\n\x13LastStatusTimestamp\x18\r \x01(\x04\x1a-\n\x0bTShardQuota\x12\x0f\n\x07ShardId\x18\x01 \x01(\x04\x12\r\n\x05Quota\x18\x02 \x01(\x04\"\x1d\n\x1bTEvGetSlowOpProfilesRequest\"\x9f\x02\n\x1cTEvGetSlowOpProfilesResponse\x12+\n\x06Status\x18\x01 \x01(\x0b\x32\x1b.NKikimrTxDataShard.TStatus\x12M\n\x08Profiles\x18\x02 \x03(\x0b\x32;.NKikimrTxDataShard.TEvGetSlowOpProfilesResponse.TOpProfile\x1a\x82\x01\n\nTOpProfile\x12\x33\n\tBasicInfo\x18\x01 \x01(\x0b\x32 .NKikimrTxDataShard.TBasicOpInfo\x12?\n\x10\x45xecutionProfile\x18\x02 \x01(\x0b\x32%.NKikimrTxDataShard.TExecutionProfile\"\x15\n\x13TEvGetRSInfoRequest\"\xef\x03\n\x14TEvGetRSInfoResponse\x12+\n\x06Status\x18\x01 \x01(\x0b\x32\x1b.NKikimrTxDataShard.TStatus\x12H\n\x0bOutReadSets\x18\x02 \x03(\x0b\x32\x33.NKikimrTxDataShard.TEvGetRSInfoResponse.TOutRSInfo\x12\x46\n\tOutRSAcks\x18\x03 \x03(\x0b\x32\x33.NKikimrTxDataShard.TEvGetRSInfoResponse.TRSAckInfo\x12J\n\rDelayedRSAcks\x18\x04 \x03(\x0b\x32\x33.NKikimrTxDataShard.TEvGetRSInfoResponse.TRSAckInfo\x1a^\n\nTOutRSInfo\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x0e\n\x06Source\x18\x03 \x01(\x04\x12\x13\n\x0b\x44\x65stination\x18\x04 \x01(\x04\x12\r\n\x05SeqNo\x18\x05 \x01(\x04\x1al\n\nTRSAckInfo\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0c\n\x04Step\x18\x02 \x01(\x04\x12\x0e\n\x06Origin\x18\x03 \x01(\x04\x12\x0e\n\x06Source\x18\x04 \x01(\x04\x12\x13\n\x0b\x44\x65stination\x18\x05 \x01(\x04\x12\r\n\x05SeqNo\x18\x06 \x01(\x04\"L\n\x1aTEvGetDataHistogramRequest\x12\x1a\n\x12\x43ollectKeySampleMs\x18\x01 \x01(\r\x12\x12\n\nActualData\x18\x02 \x01(\x08\"\xec\x04\n\x1bTEvGetDataHistogramResponse\x12+\n\x06Status\x18\x01 \x01(\x0b\x32\x1b.NKikimrTxDataShard.TStatus\x12Y\n\x0fTableHistograms\x18\x02 \x03(\x0b\x32@.NKikimrTxDataShard.TEvGetDataHistogramResponse.TTableHistograms\x1a\x32\n\x0eTHistogramItem\x12\r\n\x05Value\x18\x01 \x01(\x04\x12\x11\n\tKeyValues\x18\x02 \x03(\t\x1a[\n\nTHistogram\x12M\n\x05Items\x18\x01 \x03(\x0b\x32>.NKikimrTxDataShard.TEvGetDataHistogramResponse.THistogramItem\x1a\xb3\x02\n\x10TTableHistograms\x12\x11\n\tTableName\x18\x01 \x01(\t\x12\x10\n\x08KeyNames\x18\x02 \x03(\t\x12Q\n\rSizeHistogram\x18\x03 \x01(\x0b\x32:.NKikimrTxDataShard.TEvGetDataHistogramResponse.THistogram\x12R\n\x0e\x43ountHistogram\x18\x04 \x01(\x0b\x32:.NKikimrTxDataShard.TEvGetDataHistogramResponse.THistogram\x12S\n\x0fKeyAccessSample\x18\x05 \x01(\x0b\x32:.NKikimrTxDataShard.TEvGetDataHistogramResponse.THistogram\"`\n!TEvRefreshVolatileSnapshotRequest\x12\x0f\n\x07OwnerId\x18\x01 \x01(\x04\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12\x0c\n\x04Step\x18\x03 \x01(\x04\x12\x0c\n\x04TxId\x18\x04 \x01(\x04\"\xd9\x02\n\"TEvRefreshVolatileSnapshotResponse\x12\x0e\n\x06Origin\x18\x01 \x01(\x04\x12\x0f\n\x07OwnerId\x18\x02 \x01(\x04\x12\x0e\n\x06PathId\x18\x03 \x01(\x04\x12\x0c\n\x04Step\x18\x04 \x01(\x04\x12\x0c\n\x04TxId\x18\x05 \x01(\x04\x12N\n\x06Status\x18\x06 \x01(\x0e\x32>.NKikimrTxDataShard.TEvRefreshVolatileSnapshotResponse.EStatus\x12\x1b\n\x13TransferredToShards\x18\x07 \x03(\x04\"y\n\x07\x45Status\x12\r\n\tREFRESHED\x10\x01\x12\x15\n\x11WRONG_SHARD_STATE\x10\x02\x12\x16\n\x12SNAPSHOT_NOT_FOUND\x10\x03\x12\x18\n\x14SNAPSHOT_TRANSFERRED\x10\x04\x12\x16\n\x12SNAPSHOT_NOT_READY\x10\x05\"`\n!TEvDiscardVolatileSnapshotRequest\x12\x0f\n\x07OwnerId\x18\x01 \x01(\x04\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12\x0c\n\x04Step\x18\x03 \x01(\x04\x12\x0c\n\x04TxId\x18\x04 \x01(\x04\"\xd9\x02\n\"TEvDiscardVolatileSnapshotResponse\x12\x0e\n\x06Origin\x18\x01 \x01(\x04\x12\x0f\n\x07OwnerId\x18\x02 \x01(\x04\x12\x0e\n\x06PathId\x18\x03 \x01(\x04\x12\x0c\n\x04Step\x18\x04 \x01(\x04\x12\x0c\n\x04TxId\x18\x05 \x01(\x04\x12N\n\x06Status\x18\x06 \x01(\x0e\x32>.NKikimrTxDataShard.TEvDiscardVolatileSnapshotResponse.EStatus\x12\x1b\n\x13TransferredToShards\x18\x07 \x03(\x04\"y\n\x07\x45Status\x12\r\n\tDISCARDED\x10\x01\x12\x15\n\x11WRONG_SHARD_STATE\x10\x02\x12\x16\n\x12SNAPSHOT_NOT_FOUND\x10\x03\x12\x18\n\x14SNAPSHOT_TRANSFERRED\x10\x04\x12\x16\n\x12SNAPSHOT_NOT_READY\x10\x05\"h\n\x1cTEvMigrateSchemeShardRequest\x12\x1c\n\x14\x43urrentSchemeShardId\x18\x01 \x01(\x06\x12\x18\n\x10NewSchemeShardId\x18\x02 \x01(\x06\x12\x10\n\x08TabletId\x18\x03 \x01(\x06\"\xb3\x01\n\x1dTEvMigrateSchemeShardResponse\x12I\n\x06Status\x18\x01 \x01(\x0e\x32\x39.NKikimrTxDataShard.TEvMigrateSchemeShardResponse.EStatus\x12\x10\n\x08TabletId\x18\x02 \x01(\x06\"5\n\x07\x45Status\x12\x0b\n\x07Success\x10\x01\x12\x0b\n\x07\x41lready\x10\x02\x12\x10\n\x0cWrongRequest\x10\x03\"}\n\x14TExpirationCondition\x12\x10\n\x08\x43olumnId\x18\x01 \x01(\r\x12\x1a\n\x12WallClockTimestamp\x18\x02 \x01(\x04\x12\x37\n\nColumnUnit\x18\x03 \x01(\x0e\x32#.NKikimrSchemeOp.TTTLSettings.EUnit\"\xb4\x01\n\x13TEvEraseRowsRequest\x12\x0f\n\x07TableId\x18\x01 \x01(\x04\x12\x14\n\x0cKeyColumnIds\x18\x02 \x03(\r\x12\x12\n\nKeyColumns\x18\x03 \x03(\x0c\x12\x15\n\rSchemaVersion\x18\x05 \x01(\x04\x12>\n\nExpiration\x18\x04 \x01(\x0b\x32(.NKikimrTxDataShard.TExpirationConditionH\x00\x42\x0b\n\tCondition\"\xd5\x03\n\x14TEvEraseRowsResponse\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\x12@\n\x06Status\x18\x02 \x01(\x0e\x32\x30.NKikimrTxDataShard.TEvEraseRowsResponse.EStatus\x12\x18\n\x10\x45rrorDescription\x18\x03 \x01(\t\"\xce\x02\n\x07\x45Status\x12\x06\n\x02OK\x10\x00\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x01\x12\x10\n\x0cSCHEME_ERROR\x10\x02\x12\x0e\n\nEXEC_ERROR\x10\x03\x12\x15\n\x11WRONG_SHARD_STATE\x10\x04\x12\x0b\n\x07UNKNOWN\x10\x05\x12\x18\n\x14\x43OORDINATOR_DECLINED\x10\n\x12\x17\n\x13\x43OORDINATOR_UNKNOWN\x10\x0b\x12\x17\n\x13SHARD_NOT_AVAILABLE\x10\x14\x12\x11\n\rSHARD_ABORTED\x10\x15\x12\x13\n\x0fSHARD_CANCELLED\x10\x16\x12\x1c\n\x18SHARD_RESULT_UNAVAILABLE\x10\x17\x12\x14\n\x10SHARD_OVERLOADED\x10\x18\x12\x13\n\x0fSHARD_TRY_LATER\x10\x19\x12\x14\n\x10SHARD_EXEC_ERROR\x10\x1a\x12\x11\n\rSHARD_UNKNOWN\x10\x1b\"\xff\x04\n\x1eTEvConditionalEraseRowsRequest\x12\x0f\n\x07TableId\x18\x01 \x01(\x04\x12\x15\n\rSchemaVersion\x18\x03 \x01(\x04\x12U\n\x07Indexes\x18\x04 \x03(\x0b\x32\x44.NKikimrTxDataShard.TEvConditionalEraseRowsRequest.TIndexDescription\x12J\n\x06Limits\x18\x05 \x01(\x0b\x32:.NKikimrTxDataShard.TEvConditionalEraseRowsRequest.TLimits\x12>\n\nExpiration\x18\x02 \x01(\x0b\x32(.NKikimrTxDataShard.TExpirationConditionH\x00\x1a\xe1\x01\n\x11TIndexDescription\x12\x0f\n\x07OwnerId\x18\x01 \x01(\x04\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12\x15\n\rSchemaVersion\x18\x03 \x01(\x04\x12\\\n\x06KeyMap\x18\x04 \x03(\x0b\x32L.NKikimrTxDataShard.TEvConditionalEraseRowsRequest.TIndexDescription.TKeyMap\x1a\x36\n\x07TKeyMap\x12\x15\n\rIndexColumnId\x18\x01 \x01(\r\x12\x14\n\x0cMainColumnId\x18\x02 \x01(\r\x1a\x61\n\x07TLimits\x12\x1d\n\rBatchMaxBytes\x18\x01 \x01(\r:\x06\x35\x31\x32\x30\x30\x30\x12\x1a\n\x0c\x42\x61tchMinKeys\x18\x02 \x01(\r:\x04\x31\x30\x30\x30\x12\x1b\n\x0c\x42\x61tchMaxKeys\x18\x03 \x01(\r:\x05\x35\x30\x30\x30\x30\x42\x0b\n\tCondition\"\x99\x03\n\x1fTEvConditionalEraseRowsResponse\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\x12K\n\x06Status\x18\x02 \x01(\x0e\x32;.NKikimrTxDataShard.TEvConditionalEraseRowsResponse.EStatus\x12\x18\n\x10\x45rrorDescription\x18\x03 \x01(\t\x12I\n\x05Stats\x18\x04 \x01(\x0b\x32:.NKikimrTxDataShard.TEvConditionalEraseRowsResponse.TStats\x1a\x33\n\x06TStats\x12\x15\n\rRowsProcessed\x18\x01 \x01(\x04\x12\x12\n\nRowsErased\x18\x02 \x01(\x04\"}\n\x07\x45Status\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x00\x12\x0b\n\x07PARTIAL\x10\x01\x12\x06\n\x02OK\x10\x02\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x03\x12\x0b\n\x07\x41\x42ORTED\x10\x04\x12\x0f\n\x0b\x45RASE_ERROR\x10\x05\x12\x0e\n\nOVERLOADED\x10\x06\x12\x10\n\x0cSCHEME_ERROR\x10\x07\"\xe6\x02\n\x1aTEvBuildIndexCreateRequest\x12\x14\n\x0c\x42uildIndexId\x18\x01 \x01(\x04\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\x12\x0f\n\x07OwnerId\x18\x03 \x01(\x04\x12\x0e\n\x06PathId\x18\x04 \x01(\x04\x12\x12\n\nTargetName\x18\x05 \x01(\t\x12\x14\n\x0cIndexColumns\x18\x06 \x03(\t\x12&\n\x08KeyRange\x18\x07 \x01(\x0b\x32\x14.NKikimrTx.TKeyRange\x12\x14\n\x0cSnapshotTxId\x18\x08 \x01(\x04\x12\x14\n\x0cSnapshotStep\x18\t \x01(\x04\x12\x14\n\x0cMaxBatchRows\x18\n \x01(\r\x12\x15\n\rMaxBatchBytes\x18\x0b \x01(\x04\x12\x17\n\x0fSeqNoGeneration\x18\x0c \x01(\x04\x12\x12\n\nSeqNoRound\x18\r \x01(\x04\x12\x12\n\nMaxRetries\x18\x0e \x01(\x04\x12\x13\n\x0b\x44\x61taColumns\x18\x0f \x03(\t\"\xa3\x04\n\x1dTEvBuildIndexProgressResponse\x12\x14\n\x0c\x42uildIndexId\x18\x01 \x01(\x04\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\x12\x0f\n\x07OwnerId\x18\x03 \x01(\x04\x12\x0e\n\x06PathId\x18\x04 \x01(\x04\x12I\n\x06Status\x18\x05 \x01(\x0e\x32\x39.NKikimrTxDataShard.TEvBuildIndexProgressResponse.EStatus\x12/\n\x0cUploadStatus\x18\x06 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x07 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12/\n\x11RequestedKeyRange\x18\x08 \x01(\x0b\x32\x14.NKikimrTx.TKeyRange\x12\x12\n\nLastKeyAck\x18\t \x01(\x0c\x12\x11\n\tRowsDelta\x18\n \x01(\x04\x12\x12\n\nBytesDelta\x18\x0b \x01(\x04\x12\x1e\n\x16RequestSeqNoGeneration\x18\x0c \x01(\x04\x12\x19\n\x11RequestSeqNoRound\x18\r \x01(\x04\"m\n\x07\x45Status\x12\x0b\n\x07INVALID\x10\x00\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x01\x12\x0e\n\nINPROGRESS\x10\x02\x12\x08\n\x04\x44ONE\x10\x03\x12\x0b\n\x07\x41\x42ORTED\x10\x04\x12\x0f\n\x0b\x42UILD_ERROR\x10\x05\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x06\"\xdb\x04\n\nTEvKqpScan\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0e\n\x06ScanId\x18\x02 \x01(\x04\x12\x13\n\x0bLocalPathId\x18\x03 \x01(\x04\x12\x11\n\tTablePath\x18\x04 \x01(\t\x12\x15\n\rSchemaVersion\x18\x05 \x01(\x04\x12\x12\n\nColumnTags\x18\x06 \x03(\r\x12\x13\n\x0b\x43olumnTypes\x18\x07 \x03(\r\x12\x30\n\x0f\x43olumnTypeInfos\x18\x16 \x03(\x0b\x32\x17.NKikimrProto.TTypeInfo\x12\x14\n\x0cSkipNullKeys\x18\x08 \x03(\x08\x12$\n\x06Ranges\x18\t \x03(\x0b\x32\x14.NKikimrTx.TKeyRange\x12*\n\x08Snapshot\x18\n \x01(\x0b\x32\x18.NKikimrKqp.TKqpSnapshot\x12\x11\n\tTimeoutMs\x18\x0c \x01(\x04\x12\x12\n\nGeneration\x18\r \x01(\r\x12\x12\n\nItemsLimit\x18\x0f \x01(\x04\x12\x0f\n\x07Reverse\x18\x10 \x01(\x08\x12\x37\n\nDataFormat\x18\x11 \x01(\x0e\x32#.NKikimrTxDataShard.EScanDataFormat\x12.\n\tStatsMode\x18\x12 \x01(\x0e\x32\x1b.NYql.NDqProto.EDqStatsMode\x12\x13\n\x0bOlapProgram\x18\x13 \x01(\x0c\x12:\n\x0fOlapProgramType\x18\x14 \x01(\x0e\x32!.NKikimrSchemeOp.EOlapProgramType\x12\x1b\n\x0c\x43ostDataOnly\x18\x15 \x01(\x08:\x05\x66\x61lseJ\x04\x08\x0b\x10\x0cJ\x04\x08\x0e\x10\x0f\"t\n\x0fTEvCompactTable\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x17\n\x0f\x43ompactBorrowed\x18\x02 \x01(\x08\x12!\n\x19\x43ompactSinglePartedShards\x18\x03 \x01(\x08\"\xdc\x01\n\x15TEvCompactTableResult\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12%\n\x06PathId\x18\x02 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x41\n\x06Status\x18\x03 \x01(\x0e\x32\x31.NKikimrTxDataShard.TEvCompactTableResult.EStatus\"G\n\x07\x45Status\x12\x06\n\x02OK\x10\x00\x12\x0e\n\nNOT_NEEDED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\x12\x0c\n\x08\x42ORROWED\x10\x03\x12\n\n\x06LOANED\x10\x04\";\n\x12TEvCompactBorrowed\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\"S\n\x18TEvCompactBorrowedResult\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12%\n\x06PathId\x18\x02 \x01(\x0b\x32\x15.NKikimrProto.TPathID\"@\n\x17TEvGetCompactTableStats\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\"\x86\x01\n\x1dTEvGetCompactTableStatsResult\x12$\n\x1c\x42\x61\x63kgroundCompactionRequests\x18\x01 \x01(\x04\x12!\n\x19\x42\x61\x63kgroundCompactionCount\x18\x02 \x01(\x04\x12\x1c\n\x14\x43ompactBorrowedCount\x18\x03 \x01(\x04\"\xb5\x03\n\x07TEvRead\x12\x0e\n\x06ReadId\x18\x01 \x01(\x04\x12-\n\x07TableId\x18\x02 \x01(\x0b\x32\x1c.NKikimrTxDataShard.TTableId\x12\x0f\n\x07\x43olumns\x18\x03 \x03(\r\x12+\n\x08Snapshot\x18\x04 \x01(\x0b\x32\x19.NKikimrProto.TRowVersion\x12\x10\n\x08LockTxId\x18\x05 \x01(\x04\x12\x12\n\nLockNodeId\x18\x0b \x01(\r\x12\x39\n\x0cResultFormat\x18\x06 \x01(\x0e\x32#.NKikimrTxDataShard.EScanDataFormat\x12\x0f\n\x07MaxRows\x18\x07 \x01(\r\x12\x10\n\x08MaxBytes\x18\x08 \x01(\r\x12\x17\n\x0fMaxRowsInResult\x18\t \x01(\r\x12\x0f\n\x07Reverse\x18\n \x01(\x08\x12\r\n\x04Keys\x18\x84\x07 \x03(\x0c\x12%\n\x06Ranges\x18\x85\x07 \x03(\x0b\x32\x14.NKikimrTx.TKeyRange\x12\x10\n\x07Program\x18\x86\x07 \x01(\x0c\x12\x37\n\x0bProgramType\x18\x87\x07 \x01(\x0e\x32!.NKikimrSchemeOp.EOlapProgramType\"Q\n\x16TReadContinuationToken\x12\x1d\n\x15\x46irstUnprocessedQuery\x18\x01 \x01(\r\x12\x18\n\x10LastProcessedKey\x18\x02 \x01(\x0c\"\xfa\x04\n\rTEvReadResult\x12\x0e\n\x06ReadId\x18\x01 \x01(\x04\x12\r\n\x05SeqNo\x18\x02 \x01(\x04\x12+\n\x06Status\x18\x03 \x01(\x0b\x32\x1b.NKikimrTxDataShard.TStatus\x12\x39\n\x0cResultFormat\x18\x04 \x01(\x0e\x32#.NKikimrTxDataShard.EScanDataFormat\x12+\n\x08Snapshot\x18\x05 \x01(\x0b\x32\x19.NKikimrProto.TRowVersion\x12\x19\n\x11\x43ontinuationToken\x18\x06 \x01(\x0c\x12\x14\n\x0cLimitReached\x18\x07 \x01(\x08\x12.\n\x05Stats\x18\x08 \x01(\x0b\x32\x1f.NKikimrQueryStats.TReadOpStats\x12\x10\n\x08\x46inished\x18\t \x01(\x08\x12*\n\x07TxLocks\x18\n \x03(\x0b\x32\x19.NKikimrTxDataShard.TLock\x12\x30\n\rBrokenTxLocks\x18\x0b \x03(\x0b\x32\x19.NKikimrTxDataShard.TLock\x12\x44\n\nArrowBatch\x18\x84\x07 \x01(\x0b\x32-.NKikimrTxDataShard.TEvReadResult.TArrowBatchH\x00\x12\x43\n\x07\x43\x65llVec\x18\x85\x07 \x01(\x0b\x32/.NKikimrTxDataShard.TEvReadResult.TCellVecBatchH\x00\x1a,\n\x0bTArrowBatch\x12\x0e\n\x06Schema\x18\x01 \x01(\x0c\x12\r\n\x05\x42\x61tch\x18\x02 \x01(\x0c\x1a\x1d\n\rTCellVecBatch\x12\x0c\n\x04Rows\x18\x01 \x03(\x0c\x42\x0c\n\nReadResult\"N\n\nTEvReadAck\x12\x0e\n\x06ReadId\x18\x01 \x01(\x04\x12\r\n\x05SeqNo\x18\x02 \x01(\x04\x12\x0f\n\x07MaxRows\x18\x03 \x01(\r\x12\x10\n\x08MaxBytes\x18\x04 \x01(\r\"\x1f\n\rTEvReadCancel\x12\x0e\n\x06ReadId\x18\x01 \x01(\x04\"\xdc\x03\n\x1aTEvApplyReplicationChanges\x12-\n\x07TableId\x18\x01 \x01(\x0b\x32\x1c.NKikimrTxDataShard.TTableId\x12\x0e\n\x06Source\x18\x02 \x01(\x0c\x12G\n\x07\x43hanges\x18\x03 \x03(\x0b\x32\x36.NKikimrTxDataShard.TEvApplyReplicationChanges.TChange\x1a&\n\x08TUpdates\x12\x0c\n\x04Tags\x18\x01 \x03(\r\x12\x0c\n\x04\x44\x61ta\x18\x02 \x01(\x0c\x1a\x8d\x02\n\x07TChange\x12\x14\n\x0cSourceOffset\x18\x01 \x01(\x03\x12\x11\n\tWriteTxId\x18\x02 \x01(\x04\x12\x0b\n\x03Key\x18\x03 \x01(\x0c\x12I\n\x06Upsert\x18\x04 \x01(\x0b\x32\x37.NKikimrTxDataShard.TEvApplyReplicationChanges.TUpdatesH\x00\x12\'\n\x05\x45rase\x18\x05 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12H\n\x05Reset\x18\x06 \x01(\x0b\x32\x37.NKikimrTxDataShard.TEvApplyReplicationChanges.TUpdatesH\x00\x42\x0e\n\x0cRowOperation\"\xa6\x03\n TEvApplyReplicationChangesResult\x12L\n\x06Status\x18\x01 \x01(\x0e\x32<.NKikimrTxDataShard.TEvApplyReplicationChangesResult.EStatus\x12L\n\x06Reason\x18\x02 \x01(\x0e\x32<.NKikimrTxDataShard.TEvApplyReplicationChangesResult.EReason\x12\x18\n\x10\x45rrorDescription\x18\x03 \x01(\t\"A\n\x07\x45Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\r\n\tSTATUS_OK\x10\x01\x12\x13\n\x0fSTATUS_REJECTED\x10\x02\"\x88\x01\n\x07\x45Reason\x12\x0f\n\x0bREASON_NONE\x10\x00\x12\x16\n\x12REASON_WRONG_STATE\x10\x01\x12\x17\n\x13REASON_SCHEME_ERROR\x10\x02\x12\x16\n\x12REASON_BAD_REQUEST\x10\x03\x12#\n\x1fREASON_UNEXPECTED_ROW_OPERATION\x10\x04\"\xa1\x01\n\x1eTEvGetReplicationSourceOffsets\x12\x0e\n\x06ReadId\x18\x01 \x01(\x04\x12-\n\x07TableId\x18\x02 \x01(\x0b\x32\x1c.NKikimrTxDataShard.TTableId\x12\x14\n\x0c\x46romSourceId\x18\x03 \x01(\x04\x12\x16\n\x0e\x46romSplitKeyId\x18\x04 \x01(\x04\x12\x12\n\nWindowSize\x18\x05 \x01(\x04\"\xa4\x02\n\x1bTEvReplicationSourceOffsets\x12\x0e\n\x06ReadId\x18\x01 \x01(\x04\x12\r\n\x05SeqNo\x18\x02 \x01(\x04\x12\x13\n\x0b\x45ndOfStream\x18\x03 \x01(\x08\x12\x12\n\nResultSize\x18\x04 \x01(\x04\x12M\n\x06Result\x18\x05 \x03(\x0b\x32=.NKikimrTxDataShard.TEvReplicationSourceOffsets.TSourceOffset\x1an\n\rTSourceOffset\x12\x10\n\x08SourceId\x18\x01 \x01(\x04\x12\x12\n\nSplitKeyId\x18\x02 \x01(\x04\x12\x0e\n\x06Source\x18\x03 \x01(\x0c\x12\x10\n\x08SplitKey\x18\x04 \x01(\x0c\x12\x15\n\tMaxOffset\x18\x05 \x01(\x03:\x02-1\"V\n\x1eTEvReplicationSourceOffsetsAck\x12\x0e\n\x06ReadId\x18\x01 \x01(\x04\x12\x10\n\x08\x41\x63kSeqNo\x18\x02 \x01(\x04\x12\x12\n\nWindowSize\x18\x03 \x01(\x04\"3\n!TEvReplicationSourceOffsetsCancel\x12\x0e\n\x06ReadId\x18\x01 \x01(\x04\"\x7f\n\x12TTxVolatileDetails\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x13\n\x0bVersionStep\x18\x02 \x01(\x04\x12\x13\n\x0bVersionTxId\x18\x03 \x01(\x04\x12\x17\n\x0b\x43ommitTxIds\x18\x04 \x03(\x04\x42\x02\x10\x01\x12\x18\n\x0c\x44\x65pendencies\x18\x05 \x03(\x04\x42\x02\x10\x01*\xa5\x02\n\x0f\x45\x44\x61tashardState\x12\x11\n\rUninitialized\x10\x00\x12\x0e\n\nWaitScheme\x10\x01\x12\t\n\x05Ready\x10\x02\x12\x0c\n\x08Readonly\x10\x03\x12\x0b\n\x07Offline\x10\x04\x12\x0e\n\nPreOffline\x10\x05\x12\n\n\x06\x46rozen\x10\x06\x12\x1f\n\x1bSplitSrcWaitForNoTxInFlight\x10\x65\x12\x18\n\x14SplitSrcMakeSnapshot\x10\x66\x12\x1b\n\x17SplitSrcSendingSnapshot\x10g\x12&\n\"SplitSrcWaitForPartitioningChanged\x10h\x12\x1e\n\x19SplitDstReceivingSnapshot\x10\xc9\x01\x12\r\n\x07Unknown\x10\xff\xff\x03*^\n\x13\x45KqpTransactionType\x12\x1b\n\x17KQP_TX_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10KQP_TX_TYPE_DATA\x10\x01\x12\x14\n\x10KQP_TX_TYPE_SCAN\x10\x02*:\n\x0f\x45ScanDataFormat\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07\x43\x45LLVEC\x10\x01\x12\t\n\x05\x41RROW\x10\x02*\xd0\x01\n\x10\x45TransactionKind\x12\x10\n\x0cTX_KIND_NONE\x10\x00\x12\x10\n\x0cTX_KIND_DATA\x10\x01\x12\x12\n\x0eTX_KIND_SCHEME\x10\x02\x12\x10\n\x0c\x44\x45PRECATED_3\x10\x03\x12\x10\n\x0c\x44\x45PRECATED_4\x10\x04\x12\x10\n\x0cTX_KIND_SCAN\x10\x05\x12\x14\n\x10TX_KIND_SNAPSHOT\x10\x06\x12\x1d\n\x19TX_KIND_DISTRIBUTED_ERASE\x10\x07\x12\x19\n\x15TX_KIND_COMMIT_WRITES\x10\x08\x42\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tx_datashard_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TTXVOLATILEDETAILS.fields_by_name['CommitTxIds']._options = None
  _TTXVOLATILEDETAILS.fields_by_name['CommitTxIds']._serialized_options = b'\020\001'
  _TTXVOLATILEDETAILS.fields_by_name['Dependencies']._options = None
  _TTXVOLATILEDETAILS.fields_by_name['Dependencies']._serialized_options = b'\020\001'
  _EDATASHARDSTATE._serialized_start=31788
  _EDATASHARDSTATE._serialized_end=32081
  _EKQPTRANSACTIONTYPE._serialized_start=32083
  _EKQPTRANSACTIONTYPE._serialized_end=32177
  _ESCANDATAFORMAT._serialized_start=32179
  _ESCANDATAFORMAT._serialized_end=32237
  _ETRANSACTIONKIND._serialized_start=32240
  _ETRANSACTIONKIND._serialized_end=32448
  _TEVGETSHARDSTATE._serialized_start=673
  _TEVGETSHARDSTATE._serialized_end=731
  _TEVGETSHARDSTATERESULT._serialized_start=733
  _TEVGETSHARDSTATERESULT._serialized_end=806
  _TSHARDOPRESULT._serialized_start=808
  _TSHARDOPRESULT._serialized_end=905
  _TEVSCHEMACHANGED._serialized_start=908
  _TEVSCHEMACHANGED._serialized_end=1099
  _TEVSCHEMACHANGEDRESULT._serialized_start=1101
  _TEVSCHEMACHANGEDRESULT._serialized_end=1139
  _TEVSTATECHANGED._serialized_start=1141
  _TEVSTATECHANGED._serialized_end=1231
  _TEVSTATECHANGEDRESULT._serialized_start=1233
  _TEVSTATECHANGEDRESULT._serialized_end=1289
  _TRWTRANSACTION._serialized_start=1291
  _TRWTRANSACTION._serialized_end=1307
  _TROTRANSACTION._serialized_start=1309
  _TROTRANSACTION._serialized_end=1325
  _TTABLEID._serialized_start=1327
  _TTABLEID._serialized_end=1394
  _TREADTABLETRANSACTION._serialized_start=1397
  _TREADTABLETRANSACTION._serialized_end=1732
  _TREADTABLETRANSACTION_TCOLUMN._serialized_start=1638
  _TREADTABLETRANSACTION_TCOLUMN._serialized_end=1732
  _TKQPLOCKS._serialized_start=1735
  _TKQPLOCKS._serialized_end=1957
  _TKQPLOCKS_ELOCKSOP._serialized_start=1890
  _TKQPLOCKS_ELOCKSOP._serialized_end=1957
  _TKQPVALIDATELOCKSRESULT._serialized_start=1959
  _TKQPVALIDATELOCKSRESULT._serialized_end=2049
  _TKQPTRANSACTION._serialized_start=2052
  _TKQPTRANSACTION._serialized_end=4179
  _TKQPTRANSACTION_TCOLUMNMETA._serialized_start=2355
  _TKQPTRANSACTION_TCOLUMNMETA._serialized_end=2451
  _TKQPTRANSACTION_TCOLUMNWRITEMETA._serialized_start=2453
  _TKQPTRANSACTION_TCOLUMNWRITEMETA._serialized_end=2563
  _TKQPTRANSACTION_TTABLEKEYRANGE._serialized_start=2565
  _TKQPTRANSACTION_TTABLEKEYRANGE._serialized_end=2641
  _TKQPTRANSACTION_TTABLEMETA._serialized_start=2644
  _TKQPTRANSACTION_TTABLEMETA._serialized_end=2785
  _TKQPTRANSACTION_TDATATASKMETA._serialized_start=2788
  _TKQPTRANSACTION_TDATATASKMETA._serialized_end=3541
  _TKQPTRANSACTION_TDATATASKMETA_TKEYRANGE._serialized_start=3027
  _TKQPTRANSACTION_TDATATASKMETA_TKEYRANGE._serialized_end=3159
  _TKQPTRANSACTION_TDATATASKMETA_TREADOPMETA._serialized_start=3162
  _TKQPTRANSACTION_TDATATASKMETA_TREADOPMETA._serialized_end=3354
  _TKQPTRANSACTION_TDATATASKMETA_TWRITEOPMETA._serialized_start=3357
  _TKQPTRANSACTION_TDATATASKMETA_TWRITEOPMETA._serialized_end=3541
  _TKQPTRANSACTION_TSCANTASKMETA._serialized_start=3544
  _TKQPTRANSACTION_TSCANTASKMETA._serialized_end=4173
  _TKQPTRANSACTION_TSCANTASKMETA_TREADOPMETA._serialized_start=4096
  _TKQPTRANSACTION_TSCANTASKMETA_TREADOPMETA._serialized_end=4167
  _TKQPREADRANGESSOURCESETTINGS._serialized_start=4182
  _TKQPREADRANGESSOURCESETTINGS._serialized_end=4689
  _TKQPTASKINFO._serialized_start=4691
  _TKQPTASKINFO._serialized_end=4767
  _TKQPREPLY._serialized_start=4769
  _TKQPREPLY._serialized_end=4875
  _TKQPREADSET._serialized_start=4878
  _TKQPREADSET._serialized_end=5011
  _TDATATRANSACTION._serialized_start=5014
  _TDATATRANSACTION._serialized_end=5591
  _TCREATEVOLATILESNAPSHOT._serialized_start=5593
  _TCREATEVOLATILESNAPSHOT._serialized_end=5684
  _TDROPVOLATILESNAPSHOT._serialized_start=5686
  _TDROPVOLATILESNAPSHOT._serialized_end=5770
  _TSNAPSHOTTRANSACTION._serialized_start=5773
  _TSNAPSHOTTRANSACTION._serialized_end=5945
  _TSNAPSHOTTRANSFERREADSET._serialized_start=5948
  _TSNAPSHOTTRANSFERREADSET._serialized_end=6335
  _TSNAPSHOTTRANSFERINFO._serialized_start=6337
  _TSNAPSHOTTRANSFERINFO._serialized_end=6375
  _TRECEIVESNAPSHOT._serialized_start=6378
  _TRECEIVESNAPSHOT._serialized_end=6535
  _TSENDSNAPSHOT._serialized_start=6538
  _TSENDSNAPSHOT._serialized_end=6687
  _TSCHEMEOPSEQNO._serialized_start=6689
  _TSCHEMEOPSEQNO._serialized_end=6740
  _TCREATEPERSISTENTSNAPSHOT._serialized_start=6742
  _TCREATEPERSISTENTSNAPSHOT._serialized_end=6816
  _TDROPPERSISTENTSNAPSHOT._serialized_start=6818
  _TDROPPERSISTENTSNAPSHOT._serialized_end=6904
  _TINITIATEBUILDINDEX._serialized_start=6907
  _TINITIATEBUILDINDEX._serialized_end=7079
  _TFINALIZEBUILDINDEX._serialized_start=7082
  _TFINALIZEBUILDINDEX._serialized_end=7290
  _TDROPINDEXNOTICE._serialized_start=7293
  _TDROPINDEXNOTICE._serialized_end=7422
  _TCREATECDCSTREAMNOTICE._serialized_start=7425
  _TCREATECDCSTREAMNOTICE._serialized_end=7605
  _TALTERCDCSTREAMNOTICE._serialized_start=7608
  _TALTERCDCSTREAMNOTICE._serialized_end=7765
  _TDROPCDCSTREAMNOTICE._serialized_start=7768
  _TDROPCDCSTREAMNOTICE._serialized_end=7902
  _TASYNCINDEXINFO._serialized_start=7904
  _TASYNCINDEXINFO._serialized_end=7921
  _TREMAPINDEXPATHID._serialized_start=7924
  _TREMAPINDEXPATHID._serialized_end=8091
  _TMOVETABLE._serialized_start=8094
  _TMOVETABLE._serialized_end=8293
  _TMOVEINDEX._serialized_start=8296
  _TMOVEINDEX._serialized_end=8434
  _TFLATSCHEMETRANSACTION._serialized_start=8437
  _TFLATSCHEMETRANSACTION._serialized_end=9659
  _TDISTRIBUTEDERASETRANSACTION._serialized_start=9662
  _TDISTRIBUTEDERASETRANSACTION._serialized_end=10054
  _TDISTRIBUTEDERASETRANSACTION_TDEPENDENT._serialized_start=9972
  _TDISTRIBUTEDERASETRANSACTION_TDEPENDENT._serialized_end=10001
  _TDISTRIBUTEDERASETRANSACTION_TDEPENDENCY._serialized_start=10003
  _TDISTRIBUTEDERASETRANSACTION_TDEPENDENCY._serialized_end=10054
  _TDISTRIBUTEDERASERS._serialized_start=10056
  _TDISTRIBUTEDERASERS._serialized_end=10100
  _TCOMMITWRITESTRANSACTION._serialized_start=10102
  _TCOMMITWRITESTRANSACTION._serialized_end=10194
  _TMVCCSNAPSHOT._serialized_start=10196
  _TMVCCSNAPSHOT._serialized_end=10239
  _TEVPROPOSETRANSACTION._serialized_start=10242
  _TEVPROPOSETRANSACTION._serialized_end=10592
  _TEVCANCELTRANSACTIONPROPOSAL._serialized_start=10594
  _TEVCANCELTRANSACTIONPROPOSAL._serialized_end=10638
  _TERROR._serialized_start=10641
  _TERROR._serialized_end=11157
  _TERROR_EKIND._serialized_start=10729
  _TERROR_EKIND._serialized_end=11157
  _TLOCK._serialized_start=11159
  _TLOCK._serialized_end=11275
  _TTABLETINFO._serialized_start=11277
  _TTABLETINFO._serialized_end=11403
  _TEVPROPOSETRANSACTIONRESULT._serialized_start=11406
  _TEVPROPOSETRANSACTIONRESULT._serialized_end=12546
  _TEVPROPOSETRANSACTIONRESULT_TREADSETINFO._serialized_start=12291
  _TEVPROPOSETRANSACTIONRESULT_TREADSETINFO._serialized_end=12336
  _TEVPROPOSETRANSACTIONRESULT_ESTATUS._serialized_start=12339
  _TEVPROPOSETRANSACTIONRESULT_ESTATUS._serialized_end=12540
  _TEVPROPOSETRANSACTIONRESTART._serialized_start=12548
  _TEVPROPOSETRANSACTIONRESTART._serialized_end=12610
  _TEVPROPOSETRANSACTIONATTACH._serialized_start=12612
  _TEVPROPOSETRANSACTIONATTACH._serialized_end=12673
  _TEVPROPOSETRANSACTIONATTACHRESULT._serialized_start=12675
  _TEVPROPOSETRANSACTIONATTACHRESULT._serialized_end=12786
  _TADDSNAPSHOTPOLICYTRANSACTION._serialized_start=12788
  _TADDSNAPSHOTPOLICYTRANSACTION._serialized_end=12885
  _TEVRETURNBORROWEDPART._serialized_start=12887
  _TEVRETURNBORROWEDPART._serialized_end=12981
  _TEVRETURNBORROWEDPARTACK._serialized_start=12983
  _TEVRETURNBORROWEDPARTACK._serialized_end=13058
  _TKEYRANGETOTABLET._serialized_start=13060
  _TKEYRANGETOTABLET._serialized_end=13159
  _TSPLITMERGEDESCRIPTION._serialized_start=13162
  _TSPLITMERGEDESCRIPTION._serialized_end=13313
  _TEVINITSPLITMERGEDESTINATION._serialized_start=13316
  _TEVINITSPLITMERGEDESTINATION._serialized_end=13616
  _TEVINITSPLITMERGEDESTINATIONACK._serialized_start=13618
  _TEVINITSPLITMERGEDESTINATIONACK._serialized_end=13694
  _TEVSPLIT._serialized_start=13696
  _TEVSPLIT._serialized_end=13801
  _TEVSPLITACK._serialized_start=13803
  _TEVSPLITACK._serialized_end=13859
  _TTABLESNAPSHOT._serialized_start=13861
  _TTABLESNAPSHOT._serialized_end=13916
  _TPERSISTENTSNAPSHOT._serialized_start=13919
  _TPERSISTENTSNAPSHOT._serialized_end=14049
  _TEVSPLITTRANSFERSNAPSHOT._serialized_start=14052
  _TEVSPLITTRANSFERSNAPSHOT._serialized_end=14762
  _TEVSPLITTRANSFERSNAPSHOTACK._serialized_start=14764
  _TEVSPLITTRANSFERSNAPSHOTACK._serialized_end=14836
  _TEVSPLITPARTITIONINGCHANGED._serialized_start=14838
  _TEVSPLITPARTITIONINGCHANGED._serialized_end=14932
  _TEVSPLITPARTITIONINGCHANGEDACK._serialized_start=14934
  _TEVSPLITPARTITIONINGCHANGEDACK._serialized_end=15009
  _TEVCANCELBACKUP._serialized_start=15011
  _TEVCANCELBACKUP._serialized_end=15065
  _TEVCANCELRESTORE._serialized_start=15067
  _TEVCANCELRESTORE._serialized_end=15123
  _TEVGETTABLESTATS._serialized_start=15125
  _TEVGETTABLESTATS._serialized_end=15242
  _TEVGETTABLESTATSRESULT._serialized_start=15245
  _TEVGETTABLESTATSRESULT._serialized_end=15540
  _TEVPERIODICTABLESTATS._serialized_start=15543
  _TEVPERIODICTABLESTATS._serialized_end=15903
  _TSERIALIZEDROWCOLUMNSSCHEME._serialized_start=15905
  _TSERIALIZEDROWCOLUMNSSCHEME._serialized_end=15980
  _TSERIALIZEDROWTOLOAD._serialized_start=15982
  _TSERIALIZEDROWTOLOAD._serialized_end=16046
  _TEVUPLOADROWSREQUEST._serialized_start=16049
  _TEVUPLOADROWSREQUEST._serialized_end=16266
  _TEVUPLOADROWSRESPONSE._serialized_start=16268
  _TEVUPLOADROWSRESPONSE._serialized_end=16351
  _TEVREADCOLUMNSREQUEST._serialized_start=16354
  _TEVREADCOLUMNSREQUEST._serialized_end=16549
  _TEVREADCOLUMNSRESPONSE._serialized_start=16552
  _TEVREADCOLUMNSRESPONSE._serialized_end=16715
  _TSTATUS._serialized_start=16717
  _TSTATUS._serialized_end=16808
  _TEVGETINFOREQUEST._serialized_start=16810
  _TEVGETINFOREQUEST._serialized_end=16829
  _TEVGETINFORESPONSE._serialized_start=16832
  _TEVGETINFORESPONSE._serialized_end=18597
  _TEVGETINFORESPONSE_TSTATS._serialized_start=17335
  _TEVGETINFORESPONSE_TSTATS._serialized_end=17485
  _TEVGETINFORESPONSE_TUSERTABLE._serialized_start=17488
  _TEVGETINFORESPONSE_TUSERTABLE._serialized_end=17749
  _TEVGETINFORESPONSE_TTABLETINFO._serialized_start=17752
  _TEVGETINFORESPONSE_TTABLETINFO._serialized_end=17901
  _TEVGETINFORESPONSE_TNAMEDVALUE._serialized_start=17903
  _TEVGETINFORESPONSE_TNAMEDVALUE._serialized_end=17945
  _TEVGETINFORESPONSE_TACTIVITIES._serialized_start=17948
  _TEVGETINFORESPONSE_TACTIVITIES._serialized_end=18409
  _TEVGETINFORESPONSE_TPIPELINECONFIG._serialized_start=18412
  _TEVGETINFORESPONSE_TPIPELINECONFIG._serialized_end=18597
  _TEVLISTOPERATIONSREQUEST._serialized_start=18599
  _TEVLISTOPERATIONSREQUEST._serialized_end=18625
  _TEVLISTOPERATIONSRESPONSE._serialized_start=18628
  _TEVLISTOPERATIONSRESPONSE._serialized_end=18988
  _TEVLISTOPERATIONSRESPONSE_TOPERATIONINFO._serialized_start=18785
  _TEVLISTOPERATIONSRESPONSE_TOPERATIONINFO._serialized_end=18988
  _TEVGETOPERATIONREQUEST._serialized_start=18990
  _TEVGETOPERATIONREQUEST._serialized_end=19028
  _TBASICOPINFO._serialized_start=19030
  _TBASICOPINFO._serialized_end=19155
  _TEXECUTIONPROFILE._serialized_start=19158
  _TEXECUTIONPROFILE._serialized_end=19389
  _TEXECUTIONPROFILE_TUNITPROFILE._serialized_start=19254
  _TEXECUTIONPROFILE_TUNITPROFILE._serialized_end=19389
  _TEVGETOPERATIONRESPONSE._serialized_start=19392
  _TEVGETOPERATIONRESPONSE._serialized_end=20481
  _TEVGETOPERATIONRESPONSE_TEXECUTIONPLAN._serialized_start=19906
  _TEVGETOPERATIONRESPONSE_TEXECUTIONPLAN._serialized_end=19978
  _TEVGETOPERATIONRESPONSE_TDEPENDENCY._serialized_start=19980
  _TEVGETOPERATIONRESPONSE_TDEPENDENCY._serialized_end=20024
  _TEVGETOPERATIONRESPONSE_TDEPENDENCIES._serialized_start=20027
  _TEVGETOPERATIONRESPONSE_TDEPENDENCIES._serialized_end=20198
  _TEVGETOPERATIONRESPONSE_TINPUTRS._serialized_start=20200
  _TEVGETOPERATIONRESPONSE_TINPUTRS._serialized_end=20242
  _TEVGETOPERATIONRESPONSE_TINPUTDATA._serialized_start=20244
  _TEVGETOPERATIONRESPONSE_TINPUTDATA._serialized_end=20352
  _TEVGETOPERATIONRESPONSE_TREADTABLESTATE._serialized_start=20354
  _TEVGETOPERATIONRESPONSE_TREADTABLESTATE._serialized_end=20481
  _TEVGETREADTABLESINKSTATEREQUEST._serialized_start=20483
  _TEVGETREADTABLESINKSTATEREQUEST._serialized_end=20530
  _TSHARD._serialized_start=20532
  _TSHARD._serialized_end=20552
  _TEVGETREADTABLESINKSTATERESPONSE._serialized_start=20555
  _TEVGETREADTABLESINKSTATERESPONSE._serialized_end=21182
  _TEVGETREADTABLESCANSTATEREQUEST._serialized_start=21184
  _TEVGETREADTABLESCANSTATEREQUEST._serialized_end=21231
  _TEVGETREADTABLESCANSTATERESPONSE._serialized_start=21234
  _TEVGETREADTABLESCANSTATERESPONSE._serialized_end=21512
  _TEVGETREADTABLESTREAMSTATEREQUEST._serialized_start=21514
  _TEVGETREADTABLESTREAMSTATEREQUEST._serialized_end=21563
  _TEVGETREADTABLESTREAMSTATERESPONSE._serialized_start=21566
  _TEVGETREADTABLESTREAMSTATERESPONSE._serialized_end=22113
  _TEVGETREADTABLESTREAMSTATERESPONSE_TSHARDQUOTA._serialized_start=22068
  _TEVGETREADTABLESTREAMSTATERESPONSE_TSHARDQUOTA._serialized_end=22113
  _TEVGETSLOWOPPROFILESREQUEST._serialized_start=22115
  _TEVGETSLOWOPPROFILESREQUEST._serialized_end=22144
  _TEVGETSLOWOPPROFILESRESPONSE._serialized_start=22147
  _TEVGETSLOWOPPROFILESRESPONSE._serialized_end=22434
  _TEVGETSLOWOPPROFILESRESPONSE_TOPPROFILE._serialized_start=22304
  _TEVGETSLOWOPPROFILESRESPONSE_TOPPROFILE._serialized_end=22434
  _TEVGETRSINFOREQUEST._serialized_start=22436
  _TEVGETRSINFOREQUEST._serialized_end=22457
  _TEVGETRSINFORESPONSE._serialized_start=22460
  _TEVGETRSINFORESPONSE._serialized_end=22955
  _TEVGETRSINFORESPONSE_TOUTRSINFO._serialized_start=22751
  _TEVGETRSINFORESPONSE_TOUTRSINFO._serialized_end=22845
  _TEVGETRSINFORESPONSE_TRSACKINFO._serialized_start=22847
  _TEVGETRSINFORESPONSE_TRSACKINFO._serialized_end=22955
  _TEVGETDATAHISTOGRAMREQUEST._serialized_start=22957
  _TEVGETDATAHISTOGRAMREQUEST._serialized_end=23033
  _TEVGETDATAHISTOGRAMRESPONSE._serialized_start=23036
  _TEVGETDATAHISTOGRAMRESPONSE._serialized_end=23656
  _TEVGETDATAHISTOGRAMRESPONSE_THISTOGRAMITEM._serialized_start=23203
  _TEVGETDATAHISTOGRAMRESPONSE_THISTOGRAMITEM._serialized_end=23253
  _TEVGETDATAHISTOGRAMRESPONSE_THISTOGRAM._serialized_start=23255
  _TEVGETDATAHISTOGRAMRESPONSE_THISTOGRAM._serialized_end=23346
  _TEVGETDATAHISTOGRAMRESPONSE_TTABLEHISTOGRAMS._serialized_start=23349
  _TEVGETDATAHISTOGRAMRESPONSE_TTABLEHISTOGRAMS._serialized_end=23656
  _TEVREFRESHVOLATILESNAPSHOTREQUEST._serialized_start=23658
  _TEVREFRESHVOLATILESNAPSHOTREQUEST._serialized_end=23754
  _TEVREFRESHVOLATILESNAPSHOTRESPONSE._serialized_start=23757
  _TEVREFRESHVOLATILESNAPSHOTRESPONSE._serialized_end=24102
  _TEVREFRESHVOLATILESNAPSHOTRESPONSE_ESTATUS._serialized_start=23981
  _TEVREFRESHVOLATILESNAPSHOTRESPONSE_ESTATUS._serialized_end=24102
  _TEVDISCARDVOLATILESNAPSHOTREQUEST._serialized_start=24104
  _TEVDISCARDVOLATILESNAPSHOTREQUEST._serialized_end=24200
  _TEVDISCARDVOLATILESNAPSHOTRESPONSE._serialized_start=24203
  _TEVDISCARDVOLATILESNAPSHOTRESPONSE._serialized_end=24548
  _TEVDISCARDVOLATILESNAPSHOTRESPONSE_ESTATUS._serialized_start=24427
  _TEVDISCARDVOLATILESNAPSHOTRESPONSE_ESTATUS._serialized_end=24548
  _TEVMIGRATESCHEMESHARDREQUEST._serialized_start=24550
  _TEVMIGRATESCHEMESHARDREQUEST._serialized_end=24654
  _TEVMIGRATESCHEMESHARDRESPONSE._serialized_start=24657
  _TEVMIGRATESCHEMESHARDRESPONSE._serialized_end=24836
  _TEVMIGRATESCHEMESHARDRESPONSE_ESTATUS._serialized_start=24783
  _TEVMIGRATESCHEMESHARDRESPONSE_ESTATUS._serialized_end=24836
  _TEXPIRATIONCONDITION._serialized_start=24838
  _TEXPIRATIONCONDITION._serialized_end=24963
  _TEVERASEROWSREQUEST._serialized_start=24966
  _TEVERASEROWSREQUEST._serialized_end=25146
  _TEVERASEROWSRESPONSE._serialized_start=25149
  _TEVERASEROWSRESPONSE._serialized_end=25618
  _TEVERASEROWSRESPONSE_ESTATUS._serialized_start=25284
  _TEVERASEROWSRESPONSE_ESTATUS._serialized_end=25618
  _TEVCONDITIONALERASEROWSREQUEST._serialized_start=25621
  _TEVCONDITIONALERASEROWSREQUEST._serialized_end=26260
  _TEVCONDITIONALERASEROWSREQUEST_TINDEXDESCRIPTION._serialized_start=25923
  _TEVCONDITIONALERASEROWSREQUEST_TINDEXDESCRIPTION._serialized_end=26148
  _TEVCONDITIONALERASEROWSREQUEST_TINDEXDESCRIPTION_TKEYMAP._serialized_start=26094
  _TEVCONDITIONALERASEROWSREQUEST_TINDEXDESCRIPTION_TKEYMAP._serialized_end=26148
  _TEVCONDITIONALERASEROWSREQUEST_TLIMITS._serialized_start=26150
  _TEVCONDITIONALERASEROWSREQUEST_TLIMITS._serialized_end=26247
  _TEVCONDITIONALERASEROWSRESPONSE._serialized_start=26263
  _TEVCONDITIONALERASEROWSRESPONSE._serialized_end=26672
  _TEVCONDITIONALERASEROWSRESPONSE_TSTATS._serialized_start=26494
  _TEVCONDITIONALERASEROWSRESPONSE_TSTATS._serialized_end=26545
  _TEVCONDITIONALERASEROWSRESPONSE_ESTATUS._serialized_start=26547
  _TEVCONDITIONALERASEROWSRESPONSE_ESTATUS._serialized_end=26672
  _TEVBUILDINDEXCREATEREQUEST._serialized_start=26675
  _TEVBUILDINDEXCREATEREQUEST._serialized_end=27033
  _TEVBUILDINDEXPROGRESSRESPONSE._serialized_start=27036
  _TEVBUILDINDEXPROGRESSRESPONSE._serialized_end=27583
  _TEVBUILDINDEXPROGRESSRESPONSE_ESTATUS._serialized_start=27474
  _TEVBUILDINDEXPROGRESSRESPONSE_ESTATUS._serialized_end=27583
  _TEVKQPSCAN._serialized_start=27586
  _TEVKQPSCAN._serialized_end=28189
  _TEVCOMPACTTABLE._serialized_start=28191
  _TEVCOMPACTTABLE._serialized_end=28307
  _TEVCOMPACTTABLERESULT._serialized_start=28310
  _TEVCOMPACTTABLERESULT._serialized_end=28530
  _TEVCOMPACTTABLERESULT_ESTATUS._serialized_start=28459
  _TEVCOMPACTTABLERESULT_ESTATUS._serialized_end=28530
  _TEVCOMPACTBORROWED._serialized_start=28532
  _TEVCOMPACTBORROWED._serialized_end=28591
  _TEVCOMPACTBORROWEDRESULT._serialized_start=28593
  _TEVCOMPACTBORROWEDRESULT._serialized_end=28676
  _TEVGETCOMPACTTABLESTATS._serialized_start=28678
  _TEVGETCOMPACTTABLESTATS._serialized_end=28742
  _TEVGETCOMPACTTABLESTATSRESULT._serialized_start=28745
  _TEVGETCOMPACTTABLESTATSRESULT._serialized_end=28879
  _TEVREAD._serialized_start=28882
  _TEVREAD._serialized_end=29319
  _TREADCONTINUATIONTOKEN._serialized_start=29321
  _TREADCONTINUATIONTOKEN._serialized_end=29402
  _TEVREADRESULT._serialized_start=29405
  _TEVREADRESULT._serialized_end=30039
  _TEVREADRESULT_TARROWBATCH._serialized_start=29950
  _TEVREADRESULT_TARROWBATCH._serialized_end=29994
  _TEVREADRESULT_TCELLVECBATCH._serialized_start=29996
  _TEVREADRESULT_TCELLVECBATCH._serialized_end=30025
  _TEVREADACK._serialized_start=30041
  _TEVREADACK._serialized_end=30119
  _TEVREADCANCEL._serialized_start=30121
  _TEVREADCANCEL._serialized_end=30152
  _TEVAPPLYREPLICATIONCHANGES._serialized_start=30155
  _TEVAPPLYREPLICATIONCHANGES._serialized_end=30631
  _TEVAPPLYREPLICATIONCHANGES_TUPDATES._serialized_start=30321
  _TEVAPPLYREPLICATIONCHANGES_TUPDATES._serialized_end=30359
  _TEVAPPLYREPLICATIONCHANGES_TCHANGE._serialized_start=30362
  _TEVAPPLYREPLICATIONCHANGES_TCHANGE._serialized_end=30631
  _TEVAPPLYREPLICATIONCHANGESRESULT._serialized_start=30634
  _TEVAPPLYREPLICATIONCHANGESRESULT._serialized_end=31056
  _TEVAPPLYREPLICATIONCHANGESRESULT_ESTATUS._serialized_start=30852
  _TEVAPPLYREPLICATIONCHANGESRESULT_ESTATUS._serialized_end=30917
  _TEVAPPLYREPLICATIONCHANGESRESULT_EREASON._serialized_start=30920
  _TEVAPPLYREPLICATIONCHANGESRESULT_EREASON._serialized_end=31056
  _TEVGETREPLICATIONSOURCEOFFSETS._serialized_start=31059
  _TEVGETREPLICATIONSOURCEOFFSETS._serialized_end=31220
  _TEVREPLICATIONSOURCEOFFSETS._serialized_start=31223
  _TEVREPLICATIONSOURCEOFFSETS._serialized_end=31515
  _TEVREPLICATIONSOURCEOFFSETS_TSOURCEOFFSET._serialized_start=31405
  _TEVREPLICATIONSOURCEOFFSETS_TSOURCEOFFSET._serialized_end=31515
  _TEVREPLICATIONSOURCEOFFSETSACK._serialized_start=31517
  _TEVREPLICATIONSOURCEOFFSETSACK._serialized_end=31603
  _TEVREPLICATIONSOURCEOFFSETSCANCEL._serialized_start=31605
  _TEVREPLICATIONSOURCEOFFSETSCANCEL._serialized_end=31656
  _TTXVOLATILEDETAILS._serialized_start=31658
  _TTXVOLATILEDETAILS._serialized_end=31785
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/base.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aydb/core/protos/base.proto\x12\x0cNKikimrProto\":\n\x0bTLogoBlobID\x12\r\n\x05RawX1\x18\x01 \x01(\x06\x12\r\n\x05RawX2\x18\x02 \x01(\x06\x12\r\n\x05RawX3\x18\x03 \x01(\x06\")\n\x0bTRowVersion\x12\x0c\n\x04Step\x18\x01 \x01(\x04\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\"+\n\x07TPathID\x12\x0f\n\x07OwnerId\x18\x01 \x01(\x06\x12\x0f\n\x07LocalId\x18\x02 \x01(\x04*\xde\x02\n\x0c\x45ReplyStatus\x12\x06\n\x02OK\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\x0b\n\x07\x41LREADY\x10\x02\x12\x0b\n\x07TIMEOUT\x10\x03\x12\x08\n\x04RACE\x10\x04\x12\n\n\x06NODATA\x10\x05\x12\x0b\n\x07\x42LOCKED\x10\x06\x12\x0c\n\x08NOTREADY\x10\x07\x12\x0b\n\x07OVERRUN\x10\x08\x12\x0c\n\x08TRYLATER\x10\t\x12\x11\n\rTRYLATER_TIME\x10\n\x12\x11\n\rTRYLATER_SIZE\x10\x0b\x12\x0c\n\x08\x44\x45\x41\x44LINE\x10\x0c\x12\r\n\tCORRUPTED\x10\r\x12\r\n\tSCHEDULED\x10\x0e\x12\x10\n\x0cOUT_OF_SPACE\x10\x0f\x12\x15\n\x11VDISK_ERROR_STATE\x10\x10\x12\x11\n\rINVALID_OWNER\x10\x11\x12\x11\n\rINVALID_ROUND\x10\x12\x12\x0b\n\x07RESTART\x10\x13\x12\x0b\n\x07NOT_YET\x10\x14\x12\x0c\n\x08NO_GROUP\x10\x15\x12\x0c\n\x07UNKNOWN\x10\xff\x01\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.base_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _EREPLYSTATUS._serialized_start=193
  _EREPLYSTATUS._serialized_end=543
  _TLOGOBLOBID._serialized_start=44
  _TLOGOBLOBID._serialized_end=102
  _TROWVERSION._serialized_start=104
  _TROWVERSION._serialized_end=145
  _TPATHID._serialized_start=147
  _TPATHID._serialized_end=190
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/folder_service/proto/config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ydb/library/folder_service/proto/config.proto\x12\x1bNKikimrProto.NFolderService\"N\n\x14TFolderServiceConfig\x12\x0e\n\x06\x45nable\x18\x01 \x01(\x08\x12\x10\n\x08\x45ndpoint\x18\x02 \x01(\t\x12\x14\n\x0cPathToRootCA\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.folder_service.proto.config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TFOLDERSERVICECONFIG._serialized_start=78
  _TFOLDERSERVICECONFIG._serialized_end=156
# @@protoc_insertion_point(module_scope)
